@@ -1,7 +1,7 @@
 # Provide shortcuts to importing Parsons submodules and set up logging
 import importlib
-import os
 import logging
+import os
 
 from parsons.etl.table import Table
 
@@ -11,17 +11,17 @@ from parsons.etl.table import Table
 
 logger = logging.getLogger(__name__)
 _handler = logging.StreamHandler()
-_formatter = logging.Formatter('%(module)s %(levelname)s %(message)s')
+_formatter = logging.Formatter("%(module)s %(levelname)s %(message)s")
 _handler.setFormatter(_formatter)
 logger.addHandler(_handler)
 
-if os.environ.get('TESTING'):
+if os.environ.get("TESTING"):
     # Log less stuff in automated tests
-    logger.setLevel('WARNING')
-elif os.environ.get('DEBUG'):
-    logger.setLevel('DEBUG')
+    logger.setLevel("WARNING")
+elif os.environ.get("DEBUG"):
+    logger.setLevel("DEBUG")
 else:
-    logger.setLevel('INFO')
+    logger.setLevel("INFO")
 
 # Table is referenced by many connectors, so we add it immediately to limit the damage
 # of circular dependencies
@@ -29,6 +29,7 @@ __all__ = ["Table"]
 for module_path, connector_name in (
     ("parsons.actblue.actblue", "ActBlue"),
     ("parsons.action_kit.action_kit", "ActionKit"),
+    ("parsons.action_builder.action_builder", "ActionBuilder"),
     ("parsons.action_network.action_network", "ActionNetwork"),
     ("parsons.airtable.airtable", "Airtable"),
     ("parsons.alchemer.alchemer", "Alchemer"),
@@ -63,6 +64,7 @@ for module_path, connector_name in (
     ("parsons.hustle.hustle", "Hustle"),
     ("parsons.mailchimp.mailchimp", "Mailchimp"),
     ("parsons.mobilize_america.ma", "MobilizeAmerica"),
+    ("parsons.nation_builder.nation_builder", "NationBuilder"),
     ("parsons.newmode.newmode", "Newmode"),
     ("parsons.ngpvan.van", "VAN"),
     ("parsons.notifications.gmail", "Gmail"),
@@ -83,12 +85,10 @@ for module_path, connector_name in (
     ("parsons.turbovote.turbovote", "TurboVote"),
     ("parsons.twilio.twilio", "Twilio"),
     ("parsons.zoom.zoom", "Zoom"),
-
 ):
     try:
         globals()[connector_name] = getattr(
-            importlib.import_module(module_path),
-            connector_name
+            importlib.import_module(module_path), connector_name
         )
         __all__.append(connector_name)
     except ImportError:
