@@ -1,5 +1,3 @@
 from parsons.actblue.actblue import ActBlue
 
-__all__ = [
-    'ActBlue'
-]
+__all__ = ["ActBlue"]
