@@ -1,5 +1,3 @@
 from parsons.action_kit.action_kit import ActionKit
 
-__all__ = [
-    'ActionKit'
-]
+__all__ = ["ActionKit"]
