@@ -1,5 +1,3 @@
 from parsons.action_network.action_network import ActionNetwork
 
-__all__ = [
-    'ActionNetwork'
-]
+__all__ = ["ActionNetwork"]
