@@ -1,13 +1,15 @@
 import json
-from parsons import Table
+import logging
 import re
+import warnings
+
+from parsons import Table
 from parsons.utilities import check_env
 from parsons.utilities.api_connector import APIConnector
-import logging
 
 logger = logging.getLogger(__name__)
 
-API_URL = 'https://actionnetwork.org/api/v2'
+API_URL = "https://actionnetwork.org/api/v2"
 
 
 class ActionNetwork(object):
@@ -18,10 +20,10 @@ class ActionNetwork(object):
     """
 
     def __init__(self, api_token=None):
-        self.api_token = check_env.check('AN_API_TOKEN', api_token)
+        self.api_token = check_env.check("AN_API_TOKEN", api_token)
         self.headers = {
             "Content-Type": "application/json",
-            "OSDI-API-Token": self.api_token
+            "OSDI-API-Token": self.api_token,
         }
         self.api_url = API_URL
         self.api = APIConnector(self.api_url, headers=self.headers)
@@ -30,13 +32,11 @@ class ActionNetwork(object):
         # returns data from one page of results
         if per_page > 25:
             per_page = 25
-            logger.info("Action Network's API will not return more than 25 entries per page. \
-            Changing per_page parameter to 25.")
-        params = {
-            "page": page,
-            "per_page": per_page,
-            "filter": filter
-        }
+            logger.info(
+                "Action Network's API will not return more than 25 entries per page. \
+            Changing per_page parameter to 25."
+            )
+        params = {"page": page, "per_page": per_page, "filter": filter}
         return self.api.get_request(url=object_name, params=params)
 
     def _get_entry_list(self, object_name, limit=None, per_page=25, filter=None):
@@ -51,7 +51,7 @@ class ActionNetwork(object):
         while True:
             response = self._get_page(object_name, page, per_page, filter=filter)
             page = page + 1
-            response_list = response['_embedded'][f"osdi:{object_name}"]
+            response_list = response["_embedded"][f"osdi:{object_name}"]
             if not response_list:
                 return Table(return_list)
             return_list.extend(response_list)
@@ -90,9 +90,20 @@ class ActionNetwork(object):
         """
         return self.api.get_request(url=f"people/{person_id}")
 
-    def upsert_person(self, email_address=None, given_name=None, family_name=None, tags=None,
-                      languages_spoken=None, postal_addresses=None, mobile_number=None,
-                      mobile_status='subscribed', **kwargs):
+    def upsert_person(
+        self,
+        email_address=None,
+        given_name=None,
+        family_name=None,
+        tags=None,
+        languages_spoken=None,
+        postal_addresses=None,
+        mobile_number=None,
+        mobile_status="subscribed",
+        background_processing=False,
+        identifiers=None,
+        **kwargs,
+    ):
         """
         Creates or updates a person record. In order to update an existing record instead of
         creating a new one, you must supply an email or mobile number which matches a record
@@ -139,6 +150,21 @@ class ActionNetwork(object):
                             - "unsubscribed"
             mobile_status:
                 'subscribed' or 'unsubscribed'
+            background_request: bool
+                If set `true`, utilize ActionNetwork's "background processing". This will return
+                an immediate success, with an empty JSON body, and send your request to the
+                background queue for eventual processing.
+                https://actionnetwork.org/docs/v2/#background-processing
+            identifiers:
+                List of strings to be used as globally unique
+                identifiers. Can be useful for matching contacts back
+                to other platforms and systems. If the identifier
+                provided is not globally unique in ActionNetwork, it will
+                simply be ignored and not added to the object. Action Network
+                also creates its own identifier for each new resouce.
+                https://actionnetwork.org/docs/v2/#resources
+                e.g.: ["foreign_system:1", "other_system:12345abcd"]
+
             **kwargs:
                 Any additional fields to store about the person. Action Network allows
                 any custom field.
@@ -150,35 +176,42 @@ class ActionNetwork(object):
         elif type(email_address) == list:
             if type(email_address[0]) == str:
                 email_addresses_field = [{"address": email} for email in email_address]
-                email_addresses_field[0]['primary'] = True
+                email_addresses_field[0]["primary"] = True
             if type(email_address[0]) == dict:
                 email_addresses_field = email_address
 
         mobile_numbers_field = None
         if type(mobile_number) == str:
-            mobile_numbers_field = [{"number": re.sub('[^0-9]', "", mobile_number),
-                                     "status": mobile_status}]
+            mobile_numbers_field = [
+                {"number": re.sub("[^0-9]", "", mobile_number), "status": mobile_status}
+            ]
         elif type(mobile_number) == int:
-            mobile_numbers_field = [{"number": str(mobile_number), "status": mobile_status}]
+            mobile_numbers_field = [
+                {"number": str(mobile_number), "status": mobile_status}
+            ]
         elif type(mobile_number) == list:
             if len(mobile_number) > 1:
-                raise('Action Network allows only 1 phone number per activist')
+                raise ("Action Network allows only 1 phone number per activist")
             if type(mobile_number[0]) == str:
-                mobile_numbers_field = [{"number": re.sub('[^0-9]', "", cell),
-                                        "status": mobile_status}
-                                        for cell in mobile_number]
-                mobile_numbers_field[0]['primary'] = True
+                mobile_numbers_field = [
+                    {"number": re.sub("[^0-9]", "", cell), "status": mobile_status}
+                    for cell in mobile_number
+                ]
+                mobile_numbers_field[0]["primary"] = True
             if type(mobile_number[0]) == int:
-                mobile_numbers_field = [{"number": cell, "status": mobile_status}
-                                        for cell in mobile_number]
-                mobile_numbers_field[0]['primary'] = True
+                mobile_numbers_field = [
+                    {"number": cell, "status": mobile_status} for cell in mobile_number
+                ]
+                mobile_numbers_field[0]["primary"] = True
             if type(mobile_number[0]) == dict:
                 mobile_numbers_field = mobile_number
 
         if not email_addresses_field and not mobile_numbers_field:
-            raise("Either email_address or mobile_number is required and can be formatted "
-                  "as a string, list of strings, a dictionary, a list of dictionaries, or "
-                  "(for mobile_number only) an integer or list of integers")
+            raise (
+                "Either email_address or mobile_number is required and can be formatted "
+                "as a string, list of strings, a dictionary, a list of dictionaries, or "
+                "(for mobile_number only) an integer or list of integers"
+            )
 
         data = {"person": {}}
 
@@ -196,32 +229,58 @@ class ActionNetwork(object):
             data["person"]["postal_addresses"] = postal_addresses
         if tags is not None:
             data["add_tags"] = tags
+        if identifiers:
+            data["person"]["identifiers"] = identifiers
         data["person"]["custom_fields"] = {**kwargs}
-        response = self.api.post_request(url=f"{self.api_url}/people", data=json.dumps(data))
-        identifiers = response['identifiers']
-        person_id = [entry_id.split(':')[1]
-                     for entry_id in identifiers if 'action_network:' in entry_id][0]
-        if response['created_date'] == response['modified_date']:
+        url = f"{self.api_url}/people"
+        if background_processing:
+            url = f"{url}?background_processing=true"
+        response = self.api.post_request(url, data=json.dumps(data))
+
+        identifiers = response["identifiers"]
+        person_id = [
+            entry_id.split(":")[1]
+            for entry_id in identifiers
+            if "action_network:" in entry_id
+        ][0]
+        if response["created_date"] == response["modified_date"]:
             logger.info(f"Entry {person_id} successfully added.")
         else:
             logger.info(f"Entry {person_id} successfully updated.")
         return response
 
-    def add_person(self, email_address=None, given_name=None, family_name=None, tags=None,
-                   languages_spoken=None, postal_addresses=None, mobile_number=None,
-                   mobile_status='subscribed', **kwargs):
+    def add_person(
+        self,
+        email_address=None,
+        given_name=None,
+        family_name=None,
+        tags=None,
+        languages_spoken=None,
+        postal_addresses=None,
+        mobile_number=None,
+        mobile_status="subscribed",
+        **kwargs,
+    ):
         """
         Creates a person in the database. WARNING: this endpoint has been deprecated in favor of
         upsert_person.
         """
-        logger.warning("Method 'add_person' has been deprecated. Please use 'upsert_person'.")
+        logger.warning(
+            "Method 'add_person' has been deprecated. Please use 'upsert_person'."
+        )
         # Pass inputs to preferred method:
-        self.upsert_person(email_address=email_address, given_name=given_name,
-                           family_name=family_name, languages_spoken=languages_spoken,
-                           postal_addresses=postal_addresses, mobile_number=mobile_number,
-                           mobile_status=mobile_status, **kwargs)
+        self.upsert_person(
+            email_address=email_address,
+            given_name=given_name,
+            family_name=family_name,
+            languages_spoken=languages_spoken,
+            postal_addresses=postal_addresses,
+            mobile_number=mobile_number,
+            mobile_status=mobile_status,
+            **kwargs,
+        )
 
-    def update_person(self, entry_id, **kwargs):
+    def update_person(self, entry_id, background_processing=False, **kwargs):
         """
         Updates a person's data in Action Network, given their Action Network ID. Note that you
         can't alter a person's tags with this method. Instead, use upsert_person.
@@ -229,6 +288,11 @@ class ActionNetwork(object):
         `Args:`
             entry_id:
                 The person's Action Network id
+            background_processing: bool
+                If set `true`, utilize ActionNetwork's "background processing". This will return
+                an immediate success, with an empty JSON body, and send your request to the
+                background queue for eventual processing.
+                https://actionnetwork.org/docs/v2/#background-processing
             **kwargs:
                 Fields to be updated. The possible fields are
                     email_address:
@@ -259,26 +323,34 @@ class ActionNetwork(object):
                         A dictionary of any other fields to store about the person.
         """
         data = {**kwargs}
-        response = self.api.put_request(url=f"{self.api_url}/people/{entry_id}",
-                                        data=json.dumps(data), success_codes=[204, 201, 200])
+        url = f"{self.api_url}/people/{entry_id}"
+        if background_processing:
+            url = f"{url}?background_processing=true"
+        response = self.api.put_request(
+            url=url,
+            data=json.dumps(data),
+            success_codes=[204, 201, 200],
+        )
         logger.info(f"Person {entry_id} successfully updated")
         return response
 
-    def get_tags(self, limit=None, per_page=25, page=None):
+    def get_tags(self, limit=None, per_page=None):
         """
         `Args:`
             limit:
                 The number of entries to return. When None, returns all entries.
-            per_page
-                The number of entries per page to return. 25 maximum.
-            page
-                Which page of results to return
+            per_page:
+                This is a deprecated argument.
         `Returns:`
             A list of JSONs of tags in Action Network.
         """
-        if page:
-            self.get_page("tags", page, per_page)
-        return self._get_entry_list("tags", limit, per_page)
+        if per_page:
+            warnings.warn(
+                "per_page is a deprecated argument on get_tags()",
+                DeprecationWarning,
+                stacklevel=2,
+            )
+        return self._get_entry_list("tags", limit)
 
     def get_tag(self, tag_id):
         """
@@ -298,13 +370,16 @@ class ActionNetwork(object):
                 The tag's name. This is the ONLY editable field
         Adds a tag to Action Network. Once created, tags CANNOT be edited or deleted.
         """
-        data = {
-            "name": name
-        }
-        response = self.api.post_request(url=f"{self.api_url}/tags", data=json.dumps(data))
-        identifiers = response['identifiers']
-        person_id = [entry_id.split(':')[1]
-                     for entry_id in identifiers if 'action_network:' in entry_id][0]
+        data = {"name": name}
+        response = self.api.post_request(
+            url=f"{self.api_url}/tags", data=json.dumps(data)
+        )
+        identifiers = response["identifiers"]
+        person_id = [
+            entry_id.split(":")[1]
+            for entry_id in identifiers
+            if "action_network:" in entry_id
+        ][0]
         logger.info(f"Tag {person_id} successfully added to tags.")
         return response
 
@@ -338,9 +413,7 @@ class ActionNetwork(object):
             Dict of Action Network Event data.
         """
 
-        data = {
-            "title": title
-        }
+        data = {"title": title}
 
         if start_date:
             start_date = str(start_date)
@@ -349,9 +422,11 @@ class ActionNetwork(object):
         if isinstance(location, dict):
             data["location"] = location
 
-        event_dict = self.api.post_request(url=f"{self.api_url}/events", data=json.dumps(data))
+        event_dict = self.api.post_request(
+            url=f"{self.api_url}/events", data=json.dumps(data)
+        )
 
-        an_event_id = event_dict["_links"]["self"]["href"].split('/')[-1]
+        an_event_id = event_dict["_links"]["self"]["href"].split("/")[-1]
         event_dict["event_id"] = an_event_id
 
         return event_dict
