@@ -1,5 +1,3 @@
 from parsons.airtable.airtable import Airtable
 
-__all__ = [
-    'Airtable'
-]
+__all__ = ["Airtable"]
