@@ -1,3 +1,3 @@
 from parsons.alchemer.alchemer import Alchemer, SurveyGizmo
 
-__all__ = ['SurveyGizmo', 'Alchemer']
+__all__ = ["SurveyGizmo", "Alchemer"]
