@@ -1,5 +1,3 @@
 from parsons.auth0.auth0 import Auth0
 
-__all__ = [
-    'Auth0'
-]
+__all__ = ["Auth0"]
