@@ -2,8 +2,4 @@ from parsons.aws.s3 import S3
 from parsons.aws.lambda_distribute import distribute_task
 from parsons.aws.aws_async import event_command
 
-__all__ = [
-    'S3',
-    'distribute_task',
-    'event_command'
-]
+__all__ = ["S3", "distribute_task", "event_command"]
