@@ -1,5 +1,3 @@
 from parsons.azure.azure_blob_storage import AzureBlobStorage
 
-__all__ = [
-    'AzureBlobStorage'
-]
+__all__ = ["AzureBlobStorage"]
