@@ -33,22 +33,31 @@ class AzureBlobStorage(object):
         `AzureBlobStorage`
     """
 
-    def __init__(self, account_name=None, credential=None, account_domain='blob.core.windows.net',
-                 account_url=None):
-        self.account_url = os.getenv('AZURE_ACCOUNT_URL', account_url)
-        self.credential = check_env.check('AZURE_CREDENTIAL', credential)
+    def __init__(
+        self,
+        account_name=None,
+        credential=None,
+        account_domain="blob.core.windows.net",
+        account_url=None,
+    ):
+        self.account_url = os.getenv("AZURE_ACCOUNT_URL", account_url)
+        self.credential = check_env.check("AZURE_CREDENTIAL", credential)
         if not self.account_url:
-            self.account_name = check_env.check('AZURE_ACCOUNT_NAME', account_name)
-            self.account_domain = check_env.check('AZURE_ACCOUNT_DOMAIN', account_domain)
-            self.account_url = f'https://{self.account_name}.{self.account_domain}/'
+            self.account_name = check_env.check("AZURE_ACCOUNT_NAME", account_name)
+            self.account_domain = check_env.check(
+                "AZURE_ACCOUNT_DOMAIN", account_domain
+            )
+            self.account_url = f"https://{self.account_name}.{self.account_domain}/"
         else:
-            if not self.account_url.startswith('http'):
-                self.account_url = f'https://{self.account_url}'
+            if not self.account_url.startswith("http"):
+                self.account_url = f"https://{self.account_url}"
             # Update the account name and domain if a URL is supplied
             parsed_url = urlparse(self.account_url)
             self.account_name = parsed_url.netloc.split(".")[0]
             self.account_domain = ".".join(parsed_url.netloc.split(".")[1:])
-        self.client = BlobServiceClient(account_url=self.account_url, credential=self.credential)
+        self.client = BlobServiceClient(
+            account_url=self.account_url, credential=self.credential
+        )
 
     def list_containers(self):
         """
@@ -59,8 +68,10 @@ class AzureBlobStorage(object):
                 List of container names
         """
 
-        container_names = [container.name for container in self.client.list_containers()]
-        logger.info(f'Found {len(container_names)} containers.')
+        container_names = [
+            container.name for container in self.client.list_containers()
+        ]
+        logger.info(f"Found {len(container_names)} containers.")
         return container_names
 
     def container_exists(self, container_name):
@@ -77,10 +88,10 @@ class AzureBlobStorage(object):
         container_client = self.get_container(container_name)
         try:
             container_client.get_container_properties()
-            logger.info(f'{container_name} exists.')
+            logger.info(f"{container_name} exists.")
             return True
         except ResourceNotFoundError:
-            logger.info(f'{container_name} does not exist.')
+            logger.info(f"{container_name} does not exist.")
             return False
 
     def get_container(self, container_name):
@@ -94,10 +105,12 @@ class AzureBlobStorage(object):
             `ContainerClient`
         """
 
-        logger.info(f'Returning {container_name} container client')
+        logger.info(f"Returning {container_name} container client")
         return self.client.get_container_client(container_name)
 
-    def create_container(self, container_name, metadata=None, public_access=None, **kwargs):
+    def create_container(
+        self, container_name, metadata=None, public_access=None, **kwargs
+    ):
         """
         Create a container
 
@@ -120,7 +133,7 @@ class AzureBlobStorage(object):
         container_client = self.client.create_container(
             container_name, metadata=metadata, public_access=public_access, **kwargs
         )
-        logger.info(f'Created {container_name} container.')
+        logger.info(f"Created {container_name} container.")
         return container_client
 
     def delete_container(self, container_name):
@@ -135,7 +148,7 @@ class AzureBlobStorage(object):
         """
 
         self.client.delete_container(container_name)
-        logger.info(f'{container_name} container deleted.')
+        logger.info(f"{container_name} container deleted.")
 
     def list_blobs(self, container_name, name_starts_with=None):
         """
@@ -153,9 +166,10 @@ class AzureBlobStorage(object):
 
         container_client = self.get_container(container_name)
         blobs = [
-            blob for blob in container_client.list_blobs(name_starts_with=name_starts_with)
+            blob
+            for blob in container_client.list_blobs(name_starts_with=name_starts_with)
         ]
-        logger.info(f'Found {len(blobs)} blobs in {container_name} container.')
+        logger.info(f"Found {len(blobs)} blobs in {container_name} container.")
         return blobs
 
     def blob_exists(self, container_name, blob_name):
@@ -174,10 +188,10 @@ class AzureBlobStorage(object):
         blob_client = self.get_blob(container_name, blob_name)
         try:
             blob_client.get_blob_properties()
-            logger.info(f'{blob_name} exists in {container_name} container.')
+            logger.info(f"{blob_name} exists in {container_name} container.")
             return True
         except ResourceNotFoundError:
-            logger.info(f'{blob_name} does not exist in {container_name} container.')
+            logger.info(f"{blob_name} does not exist in {container_name} container.")
             return False
 
     def get_blob(self, container_name, blob_name):
@@ -194,11 +208,18 @@ class AzureBlobStorage(object):
         """
 
         blob_client = self.client.get_blob_client(container_name, blob_name)
-        logger.info(f'Got {blob_name} blob from {container_name} container.')
+        logger.info(f"Got {blob_name} blob from {container_name} container.")
         return blob_client
 
-    def get_blob_url(self, container_name, blob_name, account_key=None, permission=None,
-                     expiry=None, start=None):
+    def get_blob_url(
+        self,
+        container_name,
+        blob_name,
+        account_key=None,
+        permission=None,
+        expiry=None,
+        start=None,
+    ):
         """
         Get a URL with a shared access signature for a blob
 
@@ -227,7 +248,7 @@ class AzureBlobStorage(object):
         if not account_key:
             if not self.credential:
                 raise ValueError(
-                    'An account shared access key must be provided if it was not on initialization'
+                    "An account shared access key must be provided if it was not on initialization"
                 )
             account_key = self.credential
 
@@ -240,7 +261,7 @@ class AzureBlobStorage(object):
             expiry=expiry,
             start=start,
         )
-        return f'{self.account_url}/{container_name}/{blob_name}?sas={sas}'
+        return f"{self.account_url}/{container_name}/{blob_name}?sas={sas}"
 
     def _get_content_settings_from_dict(self, kwargs_dict):
         """
@@ -259,8 +280,12 @@ class AzureBlobStorage(object):
         content_settings = None
         content_settings_dict = {}
         content_settings_keys = [
-            'content_type', 'content_encoding', 'content_language', 'content_disposition',
-            'cache_control', 'content_md5'
+            "content_type",
+            "content_encoding",
+            "content_language",
+            "content_disposition",
+            "cache_control",
+            "content_md5",
         ]
         kwarg_keys = list(kwargs_copy.keys())
         for key in kwarg_keys:
@@ -296,7 +321,7 @@ class AzureBlobStorage(object):
         # Move all content_settings keys into a ContentSettings object
         content_settings, kwargs_dict = self._get_content_settings_from_dict(kwargs)
 
-        with open(local_path, 'rb') as f:
+        with open(local_path, "rb") as f:
             data = f.read()
 
         blob_client = blob_client.upload_blob(
@@ -305,7 +330,7 @@ class AzureBlobStorage(object):
             content_settings=content_settings,
             **kwargs_dict,
         )
-        logger.info(f'{blob_name} blob put in {container_name} container')
+        logger.info(f"{blob_name} blob put in {container_name} container")
 
         # Return refreshed BlobClient object
         return self.get_blob(container_name, blob_name)
@@ -329,14 +354,14 @@ class AzureBlobStorage(object):
         """
 
         if not local_path:
-            local_path = files.create_temp_file_for_path('TEMPFILEAZURE')
+            local_path = files.create_temp_file_for_path("TEMPFILEAZURE")
 
         blob_client = self.get_blob(container_name, blob_name)
 
-        logger.info(f'Downloading {blob_name} blob from {container_name} container.')
-        with open(local_path, 'wb') as f:
+        logger.info(f"Downloading {blob_name} blob from {container_name} container.")
+        with open(local_path, "wb") as f:
             blob_client.download_blob().readinto(f)
-        logger.info(f'{blob_name} blob saved to {local_path}.')
+        logger.info(f"{blob_name} blob saved to {local_path}.")
 
         return local_path
 
@@ -355,9 +380,9 @@ class AzureBlobStorage(object):
 
         blob_client = self.get_blob(container_name, blob_name)
         blob_client.delete_blob()
-        logger.info(f'{blob_name} blob in {container_name} container deleted.')
+        logger.info(f"{blob_name} blob in {container_name} container deleted.")
 
-    def upload_table(self, table, container_name, blob_name, data_type='csv', **kwargs):
+    def upload_table(self, table, container_name, blob_name, data_type="csv", **kwargs):
         """
         Load the data from a Parsons table into a blob.
 
@@ -376,14 +401,16 @@ class AzureBlobStorage(object):
             `BlobClient`
         """
 
-        if data_type == 'csv':
+        if data_type == "csv":
             local_path = table.to_csv()
-            content_type = 'text/csv'
-        elif data_type == 'json':
+            content_type = "text/csv"
+        elif data_type == "json":
             local_path = table.to_json()
-            content_type = 'application/json'
+            content_type = "application/json"
         else:
-            raise ValueError(f'Unknown data_type value ({data_type}): must be one of: csv or json')
+            raise ValueError(
+                f"Unknown data_type value ({data_type}): must be one of: csv or json"
+            )
 
         return self.put_blob(
             container_name, blob_name, local_path, content_type=content_type, **kwargs
