@@ -1,5 +1,3 @@
 from parsons.bill_com.bill_com import BillCom
 
-__all__ = [
-    'BillCom'
-]
+__all__ = ["BillCom"]
