@@ -1,5 +1,3 @@
 from parsons.bloomerang.bloomerang import Bloomerang
 
-__all__ = [
-    'Bloomerang'
-]
+__all__ = ["Bloomerang"]
