@@ -1,5 +1,3 @@
 from parsons.box.box import Box
 
-__all__ = [
-    'Box'
-]
+__all__ = ["Box"]
