@@ -29,7 +29,7 @@ import tempfile
 
 logger = logging.getLogger(__name__)
 
-DEFAULT_FOLDER_ID = '0'
+DEFAULT_FOLDER_ID = "0"
 
 
 class Box(object):
@@ -56,18 +56,17 @@ class Box(object):
     that contain many items. If performance is an issue, please use the
     corresponding folder_id/file_id methods for each function.
     """
+
     # In what formats can we upload/save Tables to Box? For now csv and JSON.
-    ALLOWED_FILE_FORMATS = ['csv', 'json']
+    ALLOWED_FILE_FORMATS = ["csv", "json"]
 
     def __init__(self, client_id=None, client_secret=None, access_token=None):
-        client_id = check_env('BOX_CLIENT_ID', client_id)
-        client_secret = check_env('BOX_CLIENT_SECRET', client_secret)
-        access_token = check_env('BOX_ACCESS_TOKEN', access_token)
+        client_id = check_env("BOX_CLIENT_ID", client_id)
+        client_secret = check_env("BOX_CLIENT_SECRET", client_secret)
+        access_token = check_env("BOX_ACCESS_TOKEN", access_token)
 
         oauth = boxsdk.OAuth2(
-            client_id=client_id,
-            client_secret=client_secret,
-            access_token=access_token
+            client_id=client_id, client_secret=client_secret, access_token=access_token
         )
         self.client = boxsdk.Client(oauth)
 
@@ -82,16 +81,17 @@ class Box(object):
         `Returns`:
             str: The Box id of the newly-created folder.
         """
-        if '/' in path:
-            parent_folder_path, folder_name = path.rsplit(sep='/', maxsplit=1)
+        if "/" in path:
+            parent_folder_path, folder_name = path.rsplit(sep="/", maxsplit=1)
             parent_folder_id = self.get_item_id(path=parent_folder_path)
         else:
             folder_name = path
             parent_folder_id = DEFAULT_FOLDER_ID
         return self.create_folder_by_id(folder_name, parent_folder_id=parent_folder_id)
 
-    def create_folder_by_id(self, folder_name,
-                            parent_folder_id=DEFAULT_FOLDER_ID) -> str:
+    def create_folder_by_id(
+        self, folder_name, parent_folder_id=DEFAULT_FOLDER_ID
+    ) -> str:
         """Create a Box folder.
 
         `Args`:
@@ -145,7 +145,7 @@ class Box(object):
         """
         self.client.file(file_id=file_id).delete()
 
-    def list(self, path='', item_type=None) -> Table:
+    def list(self, path="", item_type=None) -> Table:
         """Return a Table of Box files and/or folders found at a path.
 
         `Args`:
@@ -166,10 +166,10 @@ class Box(object):
         return self.list_items_by_id(folder_id=folder_id, item_type=item_type)
 
     def list_items_by_id(self, folder_id=DEFAULT_FOLDER_ID, item_type=None) -> Table:
-        url = 'https://api.box.com/2.0/folders/' + folder_id
-        json_response = self.client.make_request('GET', url)
+        url = "https://api.box.com/2.0/folders/" + folder_id
+        json_response = self.client.make_request("GET", url)
 
-        items = Table(json_response.json()['item_collection']['entries'])
+        items = Table(json_response.json()["item_collection"]["entries"])
         if item_type:
             items = items.select_rows(lambda row: row.type == item_type)
         return items
@@ -184,7 +184,7 @@ class Box(object):
         `Returns`: Table
             A Parsons table of files and their attributes.
         """
-        return self.list_items_by_id(folder_id=folder_id, item_type='file')
+        return self.list_items_by_id(folder_id=folder_id, item_type="file")
 
     def list_folders_by_id(self, folder_id=DEFAULT_FOLDER_ID) -> Table:
         """List all Box folders.
@@ -196,9 +196,9 @@ class Box(object):
         `Returns`: Table
             A Parsons table of folders and their attributes.
         """
-        return self.list_items_by_id(folder_id=folder_id, item_type='folder')
+        return self.list_items_by_id(folder_id=folder_id, item_type="folder")
 
-    def upload_table(self, table, path='', format='csv') -> boxsdk.object.file.File:
+    def upload_table(self, table, path="", format="csv") -> boxsdk.object.file.File:
         """Save the passed table to Box.
 
         `Args`:
@@ -212,18 +212,20 @@ class Box(object):
         `Returns`: BoxFile
             A Box File object
         """
-        if '/' in path:
-            folder_path, file_name = path.rsplit(sep='/', maxsplit=1)
+        if "/" in path:
+            folder_path, file_name = path.rsplit(sep="/", maxsplit=1)
             folder_id = self.get_item_id(path=folder_path)
         else:  # pragma: no cover
             file_name = path
             folder_id = DEFAULT_FOLDER_ID
 
-        return self.upload_table_to_folder_id(table=table, file_name=file_name,
-                                              folder_id=folder_id, format=format)
+        return self.upload_table_to_folder_id(
+            table=table, file_name=file_name, folder_id=folder_id, format=format
+        )
 
-    def upload_table_to_folder_id(self, table, file_name, folder_id=DEFAULT_FOLDER_ID,
-                                  format='csv') -> boxsdk.object.file.File:
+    def upload_table_to_folder_id(
+        self, table, file_name, folder_id=DEFAULT_FOLDER_ID, format="csv"
+    ) -> boxsdk.object.file.File:
         """Save the passed table to Box.
 
         `Args`:
@@ -241,23 +243,27 @@ class Box(object):
         """
 
         if format not in self.ALLOWED_FILE_FORMATS:
-            raise ValueError(f'Format argument to upload_table() must be in one '
-                             f'of {self.ALLOWED_FILE_FORMATS}; found "{format}"')
+            raise ValueError(
+                f"Format argument to upload_table() must be in one "
+                f'of {self.ALLOWED_FILE_FORMATS}; found "{format}"'
+            )
 
         # Create a temp directory in which we will let Parsons create a
         # file. Both will go away automatically when we leave scope.
         with tempfile.TemporaryDirectory() as temp_dir_name:
-            temp_file_path = temp_dir_name + '/table.tmp'
-            if format == 'csv':
+            temp_file_path = temp_dir_name + "/table.tmp"
+            if format == "csv":
                 table.to_csv(local_path=temp_file_path)
-            elif format == 'json':
+            elif format == "json":
                 table.to_json(local_path=temp_file_path)
             else:
-                raise SystemError(f'Got (theoretically) impossible '
-                                  f'format option "{format}"')  # pragma: no cover
+                raise SystemError(
+                    f"Got (theoretically) impossible " f'format option "{format}"'
+                )  # pragma: no cover
 
-            new_file = self.client.folder(folder_id).upload(file_path=temp_file_path,
-                                                            file_name=file_name)
+            new_file = self.client.folder(folder_id).upload(
+                file_path=temp_file_path, file_name=file_name
+            )
         return new_file
 
     def download_file(self, path: str, local_path: str = None) -> str:
@@ -283,12 +289,12 @@ class Box(object):
 
         file_id = self.get_item_id(path)
 
-        with open(local_path, 'wb') as output_file:
+        with open(local_path, "wb") as output_file:
             self.client.file(file_id).download_to(output_file)
 
         return local_path
 
-    def get_table(self, path, format='csv') -> Table:
+    def get_table(self, path, format="csv") -> Table:
         """Get a table that has been saved to Box in csv or JSON format.
 
         `Args`:
@@ -303,7 +309,7 @@ class Box(object):
         file_id = self.get_item_id(path)
         return self.get_table_by_file_id(file_id=file_id, format=format)
 
-    def get_table_by_file_id(self, file_id, format='csv') -> Table:
+    def get_table_by_file_id(self, file_id, format="csv") -> Table:
         """Get a table that has been saved to Box in csv or JSON format.
 
         `Args`:
@@ -316,22 +322,25 @@ class Box(object):
             A Parsons Table.
         """
         if format not in self.ALLOWED_FILE_FORMATS:
-            raise ValueError(f'Format argument to upload_table() must be in one '
-                             f'of {self.ALLOWED_FILE_FORMATS}; found "{format}"')
+            raise ValueError(
+                f"Format argument to upload_table() must be in one "
+                f'of {self.ALLOWED_FILE_FORMATS}; found "{format}"'
+            )
 
         # Temp file will be around as long as enclosing process is running,
         # which we need, because the Table we return will continue to use it.
         output_file_name = create_temp_file()
-        with open(output_file_name, 'wb') as output_file:
+        with open(output_file_name, "wb") as output_file:
             self.client.file(file_id).download_to(output_file)
 
-        if format == 'csv':
+        if format == "csv":
             return Table.from_csv(output_file_name)
-        elif format == 'json':
+        elif format == "json":
             return Table.from_json(output_file_name)
         else:
-            raise SystemError(f'Got (theoretically) impossible '
-                              f'format option "{format}"')  # pragma: no cover
+            raise SystemError(
+                f"Got (theoretically) impossible " f'format option "{format}"'
+            )  # pragma: no cover
 
     def get_item_id(self, path, base_folder_id=DEFAULT_FOLDER_ID) -> str:
         """Given a path-like object, try to return the id for the file or
@@ -356,14 +365,14 @@ class Box(object):
         try:
             # Grab the leftmost element in the path - this is what we're
             # looking for in this folder.
-            if '/' in path:
-                this_element, path = path.split(sep='/', maxsplit=1)
-                if path == '':
+            if "/" in path:
+                this_element, path = path.split(sep="/", maxsplit=1)
+                if path == "":
                     raise ValueError('Illegal trailing "/" in file path')
 
             else:
                 this_element = path
-                path = ''
+                path = ""
 
             # Look in our current base_folder for an item whose name matches the
             # current element. If we're at initial, non-recursed call, base_folder
@@ -383,7 +392,7 @@ class Box(object):
 
             # If there *are* more elements in the path, we need to check that this item is
             # in fact a folder so we can recurse and search inside it.
-            if item.type != 'folder':
+            if item.type != "folder":
                 raise ValueError(f'Invalid folder "{this_element}"')
 
             return self.get_item_id(path=path, base_folder_id=item_id)
