@@ -1,5 +1,3 @@
 from parsons.braintree.braintree import Braintree
 
-__all__ = [
-    'Braintree'
-]
+__all__ = ["Braintree"]
