@@ -1,5 +1,3 @@
 from parsons.capitol_canary.capitol_canary import CapitolCanary
 
-__all__ = [
-    'CapitolCanary'
-]
+__all__ = ["CapitolCanary"]
