@@ -1,5 +1,3 @@
 from parsons.civis.civisclient import CivisClient
 
-__all__ = [
-    'CivisClient'
-]
+__all__ = ["CivisClient"]
