@@ -1,5 +1,3 @@
 from parsons.controlshift.controlshift import Controlshift
 
-__all__ = [
-    'Controlshift'
-]
+__all__ = ["Controlshift"]
