@@ -1,5 +1,3 @@
 from parsons.copper.copper import Copper
 
-__all__ = [
-    'Copper'
-]
+__all__ = ["Copper"]
