@@ -1,5 +1,3 @@
 from parsons.crowdtangle.crowdtangle import CrowdTangle
 
-__all__ = [
-    'CrowdTangle'
-]
+__all__ = ["CrowdTangle"]
