@@ -1,5 +1,3 @@
 from parsons.databases.database.database import DatabaseCreateStatement
 
-__all__ = [
-    'DatabaseCreateStatement'
-]
+__all__ = ["DatabaseCreateStatement"]
