@@ -1,5 +1,3 @@
 from parsons.databases.mysql.mysql import MySQL
 
-__all__ = [
-    'MySQL'
-]
+__all__ = ["MySQL"]
