@@ -1,5 +1,3 @@
 from parsons.databases.postgres.postgres import Postgres
 
-__all__ = [
-    'Postgres'
-]
+__all__ = ["Postgres"]
