@@ -28,27 +28,31 @@ class Postgres(PostgresCore, Alchemy):
             Seconds to timeout if connection not established.
     """
 
-    def __init__(self, username=None, password=None, host=None, db=None, port=5432, timeout=10):
+    def __init__(
+        self, username=None, password=None, host=None, db=None, port=5432, timeout=10
+    ):
         super().__init__()
 
-        self.username = username or os.environ.get('PGUSER')
-        self.password = password or os.environ.get('PGPASSWORD')
-        self.host = host or os.environ.get('PGHOST')
-        self.db = db or os.environ.get('PGDATABASE')
-        self.port = port or os.environ.get('PGPORT')
+        self.username = username or os.environ.get("PGUSER")
+        self.password = password or os.environ.get("PGPASSWORD")
+        self.host = host or os.environ.get("PGHOST")
+        self.db = db or os.environ.get("PGDATABASE")
+        self.port = port or os.environ.get("PGPORT")
 
         # Check if there is a pgpass file. Psycopg2 will search for this file first when
         # creating a connection.
-        pgpass = os.path.isfile(os.path.expanduser('~/.pgpass'))
+        pgpass = os.path.isfile(os.path.expanduser("~/.pgpass"))
 
         if not any([self.username, self.password, self.host, self.db]) and not pgpass:
-            raise ValueError('Connection arguments missing. Please pass as a pgpass file, kwargs',
-                             'or env variables.')
+            raise ValueError(
+                "Connection arguments missing. Please pass as a pgpass file, kwargs",
+                "or env variables.",
+            )
 
         self.timeout = timeout
-        self.dialect = 'postgres'
+        self.dialect = "postgres"
 
-    def copy(self, tbl, table_name, if_exists='fail', strict_length=False):
+    def copy(self, tbl, table_name, if_exists="fail", strict_length=False):
         """
         Copy a :ref:`parsons-table` to Postgres.
 
@@ -74,16 +78,18 @@ class Postgres(PostgresCore, Alchemy):
 
                 # Create the table
                 # To Do: Pass in the advanced configuration parameters.
-                sql = self.create_statement(tbl, table_name, strict_length=strict_length)
+                sql = self.create_statement(
+                    tbl, table_name, strict_length=strict_length
+                )
 
                 self.query_with_connection(sql, connection, commit=False)
-                logger.info(f'{table_name} created.')
+                logger.info(f"{table_name} created.")
 
             sql = f"COPY {table_name} FROM STDIN CSV HEADER;"
 
             with self.cursor(connection) as cursor:
                 cursor.copy_expert(sql, open(tbl.to_csv(), "r"))
-                logger.info(f'{tbl.num_rows} rows copied to {table_name}.')
+                logger.info(f"{tbl.num_rows} rows copied to {table_name}.")
 
     def table(self, table_name):
         # Return a Postgres table object
