@@ -1,5 +1,3 @@
 from parsons.databases.redshift.redshift import Redshift
 
-__all__ = [
-    'Redshift'
-]
+__all__ = ["Redshift"]
