@@ -1,6 +1,6 @@
 COL_NAME_MAX_LEN = 120
 
-FLOAT = 'float'
+FLOAT = "float"
 
 REPLACE_CHARS = {" ": ""}
 
