@@ -2,8 +2,4 @@ from parsons.etl.table import Table
 from parsons.etl.tofrom import ToFrom
 from parsons.etl.etl import ETL
 
-__all__ = [
-    'ETL',
-    'Table',
-    'ToFrom'
-]
+__all__ = ["ETL", "Table", "ToFrom"]
