@@ -1,5 +1,3 @@
 from parsons.facebook_ads.facebook_ads import FacebookAds
 
-__all__ = [
-    'FacebookAds'
-]
+__all__ = ["FacebookAds"]
