@@ -1,5 +1,3 @@
 from parsons.freshdesk.freshdesk import Freshdesk
 
-__all__ = [
-    'Freshdesk'
-]
+__all__ = ["Freshdesk"]
