@@ -1,5 +1,3 @@
 from parsons.geocode.census_geocoder import CensusGeocoder
 
-__all__ = [
-    'CensusGeocoder'
-]
+__all__ = ["CensusGeocoder"]
