@@ -1,5 +1,3 @@
 from parsons.github.github import GitHub
 
-__all__ = [
-    'GitHub'
-]
+__all__ = ["GitHub"]
