@@ -25,40 +25,48 @@ class GoogleAdmin(object):
     def __init__(self, app_creds=None, sub=None):
         setup_google_application_credentials(app_creds)
 
-        self.client = ServiceAccountCredentials.from_json_keyfile_name(
-            os.environ['GOOGLE_APPLICATION_CREDENTIALS'],
-            ['https://www.googleapis.com/auth/admin.directory.group']
-        ).create_delegated(sub).authorize(httplib2.Http())
+        self.client = (
+            ServiceAccountCredentials.from_json_keyfile_name(
+                os.environ["GOOGLE_APPLICATION_CREDENTIALS"],
+                ["https://www.googleapis.com/auth/admin.directory.group"],
+            )
+            .create_delegated(sub)
+            .authorize(httplib2.Http())
+        )
 
     def _paginate_request(self, endpoint, collection, params=None):
         # Build query params
         param_arr = []
-        param_str = ''
+        param_str = ""
         if params:
             for key, value in params.items():
-                param_arr.append(key + '=' + value)
-            param_str = '?' + '&'.join(param_arr)
+                param_arr.append(key + "=" + value)
+            param_str = "?" + "&".join(param_arr)
 
         # Make API call
-        req_url = 'https://admin.googleapis.com/admin/directory/v1/' + endpoint
+        req_url = "https://admin.googleapis.com/admin/directory/v1/" + endpoint
 
         # Return type from Google Admin is a tuple of length 2. Extract desired result from 2nd item
         # in tuple and convert to json
-        res = json.loads(self.client.request(req_url + param_str, 'GET')[1].decode('utf-8'))
+        res = json.loads(
+            self.client.request(req_url + param_str, "GET")[1].decode("utf-8")
+        )
 
         # Paginate
         ret = []
         if collection in res:
             ret = res[collection]
 
-            while('nextPageToken' in res):
-                if param_arr[-1][0:10] != 'pageToken=':
-                    param_arr.append('pageToken=' + res['nextPageToken'])
+            while "nextPageToken" in res:
+                if param_arr[-1][0:10] != "pageToken=":
+                    param_arr.append("pageToken=" + res["nextPageToken"])
                 else:
-                    param_arr[-1] = 'pageToken=' + res['nextPageToken']
-                res = json.loads(self.client.request(
-                    req_url + '?' + '&'.join(param_arr), 'GET'
-                )[1].decode('utf-8'))
+                    param_arr[-1] = "pageToken=" + res["nextPageToken"]
+                res = json.loads(
+                    self.client.request(req_url + "?" + "&".join(param_arr), "GET")[
+                        1
+                    ].decode("utf-8")
+                )
                 ret += res[collection]
 
         return Table(ret)
@@ -76,7 +84,9 @@ class GoogleAdmin(object):
         `Returns:`
             Table Class
         """
-        return self._paginate_request('groups/' + group_key + '/aliases', 'aliases', params)
+        return self._paginate_request(
+            "groups/" + group_key + "/aliases", "aliases", params
+        )
 
     def get_all_group_members(self, group_key, params=None):
         """
@@ -91,7 +101,9 @@ class GoogleAdmin(object):
         `Returns:`
             Table Class
         """
-        return self._paginate_request('groups/' + group_key + '/members', 'members', params)
+        return self._paginate_request(
+            "groups/" + group_key + "/members", "members", params
+        )
 
     def get_all_groups(self, params=None):
         """
@@ -103,4 +115,4 @@ class GoogleAdmin(object):
         `Returns:`
             Table Class
         """
-        return self._paginate_request('groups', 'groups', params)
+        return self._paginate_request("groups", "groups", params)
