@@ -28,12 +28,14 @@ class GoogleSheets:
     def __init__(self, google_keyfile_dict=None, subject=None):
 
         scope = [
-            'https://spreadsheets.google.com/feeds',
-            'https://www.googleapis.com/auth/drive',
-            ]
+            "https://spreadsheets.google.com/feeds",
+            "https://www.googleapis.com/auth/drive",
+        ]
 
-        setup_google_application_credentials(google_keyfile_dict, 'GOOGLE_DRIVE_CREDENTIALS')
-        google_credential_file = open(os.environ['GOOGLE_DRIVE_CREDENTIALS'])
+        setup_google_application_credentials(
+            google_keyfile_dict, "GOOGLE_DRIVE_CREDENTIALS"
+        )
+        google_credential_file = open(os.environ["GOOGLE_DRIVE_CREDENTIALS"])
         credentials_dict = json.load(google_credential_file)
 
         credentials = Credentials.from_service_account_info(
@@ -47,12 +49,16 @@ class GoogleSheets:
 
         # Check if the worksheet is an integer, if so find the sheet by index
         if isinstance(worksheet, int):
-            return self.gspread_client.open_by_key(spreadsheet_id).get_worksheet(worksheet)
+            return self.gspread_client.open_by_key(spreadsheet_id).get_worksheet(
+                worksheet
+            )
 
         elif isinstance(worksheet, str):
             idx = self.list_worksheets(spreadsheet_id).index(worksheet)
             try:
-                return self.gspread_client.open_by_key(spreadsheet_id).get_worksheet(idx)
+                return self.gspread_client.open_by_key(spreadsheet_id).get_worksheet(
+                    idx
+                )
             except:  # noqa: E722
                 raise ValueError(f"Couldn't find worksheet {worksheet}")
 
@@ -111,11 +117,19 @@ class GoogleSheets:
 
         worksheet = self._get_worksheet(spreadsheet_id, worksheet)
         tbl = Table(worksheet.get_all_values())
-        logger.info(f'Retrieved worksheet with {tbl.num_rows} rows.')
+        logger.info(f"Retrieved worksheet with {tbl.num_rows} rows.")
         return tbl
 
-    def share_spreadsheet(self, spreadsheet_id, sharee, share_type='user', role='reader',
-                          notify=True, notify_message=None, with_link=False):
+    def share_spreadsheet(
+        self,
+        spreadsheet_id,
+        sharee,
+        share_type="user",
+        role="reader",
+        notify=True,
+        notify_message=None,
+        with_link=False,
+    ):
         """
         Share a spreadsheet with a user, group of users, domain and/or the public.
 
@@ -140,9 +154,15 @@ class GoogleSheets:
         """
 
         spreadsheet = self.gspread_client.open_by_key(spreadsheet_id)
-        spreadsheet.share(sharee, share_type, role, notify=notify,
-                          email_message=notify_message, with_link=with_link)
-        logger.info(f'Shared spreadsheet {spreadsheet_id}.')
+        spreadsheet.share(
+            sharee,
+            share_type,
+            role,
+            notify=notify,
+            email_message=notify_message,
+            with_link=with_link,
+        )
+        logger.info(f"Shared spreadsheet {spreadsheet_id}.")
 
     def get_spreadsheet_permissions(self, spreadsheet_id):
         """
@@ -158,7 +178,7 @@ class GoogleSheets:
 
         spreadsheet = self.gspread_client.open_by_key(spreadsheet_id)
         tbl = Table(spreadsheet.list_permissions())
-        logger.info(f'Retrieved permissions for {spreadsheet_id} spreadsheet.')
+        logger.info(f"Retrieved permissions for {spreadsheet_id} spreadsheet.")
         return tbl
 
     def create_spreadsheet(self, title, editor_email=None, folder_id=None):
@@ -188,11 +208,11 @@ class GoogleSheets:
             self.gspread_client.insert_permission(
                 spreadsheet.id,
                 editor_email,
-                perm_type='user',
-                role='writer',
+                perm_type="user",
+                role="writer",
             )
 
-        logger.info(f'Created spreadsheet {spreadsheet.id}')
+        logger.info(f"Created spreadsheet {spreadsheet.id}")
         return spreadsheet.id
 
     def delete_spreadsheet(self, spreadsheet_id):
@@ -204,7 +224,7 @@ class GoogleSheets:
                 The ID of the spreadsheet (Tip: Get this from the spreadsheet URL)
         """
         self.gspread_client.del_spreadsheet(spreadsheet_id)
-        logger.info(f'Deleted spreadsheet {spreadsheet_id}')
+        logger.info(f"Deleted spreadsheet {spreadsheet_id}")
 
     def add_sheet(self, spreadsheet_id, title=None, rows=100, cols=25):
         """
@@ -225,11 +245,12 @@ class GoogleSheets:
         spreadsheet = self.gspread_client.open_by_key(spreadsheet_id)
         spreadsheet.add_worksheet(title, rows, cols)
         sheet_count = len(spreadsheet.worksheets())
-        logger.info('Created worksheet.')
-        return (sheet_count-1)
+        logger.info("Created worksheet.")
+        return sheet_count - 1
 
-    def append_to_sheet(self, spreadsheet_id, table, worksheet=0, user_entered_value=False,
-                        **kwargs):
+    def append_to_sheet(
+        self, spreadsheet_id, table, worksheet=0, user_entered_value=False, **kwargs
+    ):
         """
         Append data from a Parsons table to a Google sheet. Note that the table's columns are
         ignored, as we'll be keeping whatever header row already exists in the Google sheet.
@@ -248,9 +269,9 @@ class GoogleSheets:
         """
 
         # This is in here to ensure backwards compatibility with previous versions of Parsons.
-        if 'sheet_index' in kwargs:
-            worksheet = kwargs['sheet_index']
-            logger.warning('Argument deprecated. Use worksheet instead.')
+        if "sheet_index" in kwargs:
+            worksheet = kwargs["sheet_index"]
+            logger.warning("Argument deprecated. Use worksheet instead.")
 
         sheet = self._get_worksheet(spreadsheet_id, worksheet)
 
@@ -261,7 +282,9 @@ class GoogleSheets:
 
         # If the existing sheet is blank, then just overwrite the table.
         if existing_table.num_rows == 0:
-            return self.overwrite_sheet(spreadsheet_id, table, worksheet, user_entered_value)
+            return self.overwrite_sheet(
+                spreadsheet_id, table, worksheet, user_entered_value
+            )
 
         cells = []
         for row_num, row in enumerate(table.data):
@@ -270,16 +293,17 @@ class GoogleSheets:
                 sheet_row_num = existing_table.num_rows + row_num + 2
                 cells.append(gspread.Cell(sheet_row_num, col_num + 1, row[col_num]))
 
-        value_input_option = 'RAW'
+        value_input_option = "RAW"
         if user_entered_value:
-            value_input_option = 'USER_ENTERED'
+            value_input_option = "USER_ENTERED"
 
         # Update the data in one batch
         sheet.update_cells(cells, value_input_option=value_input_option)
-        logger.info(f'Appended {table.num_rows} rows to worksheet.')
+        logger.info(f"Appended {table.num_rows} rows to worksheet.")
 
-    def overwrite_sheet(self, spreadsheet_id, table, worksheet=0, user_entered_value=False,
-                        **kwargs):
+    def overwrite_sheet(
+        self, spreadsheet_id, table, worksheet=0, user_entered_value=False, **kwargs
+    ):
         """
         Replace the data in a Google sheet with a Parsons table, using the table's columns as the
         first row.
@@ -298,16 +322,16 @@ class GoogleSheets:
         """
 
         # This is in here to ensure backwards compatibility with previous versions of Parsons.
-        if 'sheet_index' in kwargs:
-            worksheet = kwargs['sheet_index']
-            logger.warning('Argument deprecated. Use worksheet instead.')
+        if "sheet_index" in kwargs:
+            worksheet = kwargs["sheet_index"]
+            logger.warning("Argument deprecated. Use worksheet instead.")
 
         sheet = self._get_worksheet(spreadsheet_id, worksheet)
         sheet.clear()
 
-        value_input_option = 'RAW'
+        value_input_option = "RAW"
         if user_entered_value:
-            value_input_option = 'USER_ENTERED'
+            value_input_option = "USER_ENTERED"
 
         # Add header row
         sheet.append_row(table.columns, value_input_option=value_input_option)
@@ -320,7 +344,7 @@ class GoogleSheets:
 
         # Update the data in one batch
         sheet.update_cells(cells, value_input_option=value_input_option)
-        logger.info('Overwrote worksheet.')
+        logger.info("Overwrote worksheet.")
 
     def format_cells(self, spreadsheet_id, range, cell_format, worksheet=0):
         """
@@ -369,22 +393,22 @@ class GoogleSheets:
 
         ws = self._get_worksheet(spreadsheet_id, worksheet)
         ws.format(range, cell_format)
-        logger.info('Formatted worksheet')
+        logger.info("Formatted worksheet")
 
     def read_sheet(self, spreadsheet_id, sheet_index=0):
         # Deprecated method v0.14 of Parsons.
 
-        logger.warning('Deprecated method. Use get_worksheet() instead.')
+        logger.warning("Deprecated method. Use get_worksheet() instead.")
         return self.get_worksheet(spreadsheet_id, sheet_index)
 
     def read_sheet_with_title(self, spreadsheet_id, title):
         # Deprecated method v0.14 of Parsons.
 
-        logger.warning('Deprecated method. Use get_worksheet() instead.')
+        logger.warning("Deprecated method. Use get_worksheet() instead.")
         return self.get_worksheet(spreadsheet_id, title)
 
     def get_sheet_index_with_title(self, spreadsheet_id, title):
         # Deprecated method v0.14 of Parsons.
 
-        logger.warning('Deprecated method. Use get_worksheet_index   instead.')
+        logger.warning("Deprecated method. Use get_worksheet_index   instead.")
         return self.get_worksheet_index(spreadsheet_id, title)
