@@ -6,8 +6,9 @@ import os
 
 
 def setup_google_application_credentials(
-        app_creds: t.Union[t.Dict, str, None],
-        env_var_name: str = 'GOOGLE_APPLICATION_CREDENTIALS') -> None:
+    app_creds: t.Union[t.Dict, str, None],
+    env_var_name: str = "GOOGLE_APPLICATION_CREDENTIALS",
+) -> None:
     # Detect if app_creds is a dict, path string or json string, and if it is a
     # json string, then convert it to a temporary file. Then set the
     # environmental variable.
@@ -16,7 +17,7 @@ def setup_google_application_credentials(
         if type(credentials) is dict:
             credentials = json.dumps(credentials)
         if json.loads(credentials):
-            creds_path = files.string_to_temp_file(credentials, suffix='.json')
+            creds_path = files.string_to_temp_file(credentials, suffix=".json")
     except ValueError:
         creds_path = credentials
 
