@@ -1,5 +1,3 @@
 from parsons.hustle.hustle import Hustle
 
-__all__ = [
-    'Hustle'
-]
+__all__ = ["Hustle"]
