@@ -7,7 +7,7 @@ import logging
 
 logger = logging.getLogger(__name__)
 
-HUSTLE_URI = 'https://api.hustle.com/v1/'
+HUSTLE_URI = "https://api.hustle.com/v1/"
 PAGE_LIMIT = 1000
 
 
@@ -29,23 +29,27 @@ class Hustle(object):
     def __init__(self, client_id, client_secret):
 
         self.uri = HUSTLE_URI
-        self.client_id = check_env.check('HUSTLE_CLIENT_ID', client_id)
-        self.client_secret = check_env.check('HUSTLE_CLIENT_SECRET', client_secret)
+        self.client_id = check_env.check("HUSTLE_CLIENT_ID", client_id)
+        self.client_secret = check_env.check("HUSTLE_CLIENT_SECRET", client_secret)
         self.token_expiration = None
         self._get_auth_token(client_id, client_secret)
 
     def _get_auth_token(self, client_id, client_secret):
         # Generate a temporary authorization token
 
-        data = {'client_id': client_id,
-                'client_secret': client_secret,
-                'grant_type': 'client_credentials'}
+        data = {
+            "client_id": client_id,
+            "client_secret": client_secret,
+            "grant_type": "client_credentials",
+        }
 
-        r = request('POST', self.uri + 'oauth/token', data=data)
+        r = request("POST", self.uri + "oauth/token", data=data)
         logger.debug(r.json())
 
-        self.auth_token = r.json()['access_token']
-        self.token_expiration = datetime.datetime.now() + datetime.timedelta(seconds=7200)
+        self.auth_token = r.json()["access_token"]
+        self.token_expiration = datetime.datetime.now() + datetime.timedelta(
+            seconds=7200
+        )
         logger.info("Authentication token generated")
 
     def _token_check(self):
@@ -62,16 +66,18 @@ class Hustle(object):
 
             pass
 
-    def _request(self, endpoint, req_type='GET', args=None, payload=None, raise_on_error=True):
+    def _request(
+        self, endpoint, req_type="GET", args=None, payload=None, raise_on_error=True
+    ):
 
         url = self.uri + endpoint
         self._token_check()
 
-        headers = {'Authorization': f'Bearer {self.auth_token}'}
+        headers = {"Authorization": f"Bearer {self.auth_token}"}
 
         parameters = {}
-        if req_type == 'GET':
-            parameters = {'limit': PAGE_LIMIT}
+        if req_type == "GET":
+            parameters = {"limit": PAGE_LIMIT}
 
         if args:
             parameters.update(args)
@@ -81,20 +87,20 @@ class Hustle(object):
         self._error_check(r, raise_on_error)
 
         # If a single item return the dict
-        if 'items' not in r.json().keys():
+        if "items" not in r.json().keys():
 
             return r.json()
 
         else:
-            result = r.json()['items']
+            result = r.json()["items"]
 
         # Pagination
-        while r.json()['pagination']['hasNextPage'] == 'true':
+        while r.json()["pagination"]["hasNextPage"] == "true":
 
-            parameters['cursor'] = r.json['pagination']['cursor']
+            parameters["cursor"] = r.json["pagination"]["cursor"]
             r = request(req_type, url, params=parameters, headers=headers)
             self._error_check(r, raise_on_error)
-            result.append(r.json()['items'])
+            result.append(r.json()["items"])
 
         return result
 
@@ -130,8 +136,8 @@ class Hustle(object):
                 See :ref:`parsons-table` for output options.
         """
 
-        tbl = Table(self._request(f'groups/{group_id}/agents'))
-        logger.info(f'Got {tbl.num_rows} agents from {group_id} group.')
+        tbl = Table(self._request(f"groups/{group_id}/agents"))
+        logger.info(f"Got {tbl.num_rows} agents from {group_id} group.")
         return tbl
 
     def get_agent(self, agent_id):
@@ -145,11 +151,13 @@ class Hustle(object):
             dict
         """
 
-        r = self._request(f'agents/{agent_id}')
-        logger.info(f'Got {agent_id} agent.')
+        r = self._request(f"agents/{agent_id}")
+        logger.info(f"Got {agent_id} agent.")
         return r
 
-    def create_agent(self, group_id, name, full_name, phone_number, send_invite=False, email=None):
+    def create_agent(
+        self, group_id, name, full_name, phone_number, send_invite=False, email=None
+    ):
         """
         Create an agent.
 
@@ -170,17 +178,21 @@ class Hustle(object):
             dict
         """
 
-        agent = {'name': name,
-                 'fullName': full_name,
-                 'phoneNumber': phone_number,
-                 'sendInvite': send_invite,
-                 'email': email}
+        agent = {
+            "name": name,
+            "fullName": full_name,
+            "phoneNumber": phone_number,
+            "sendInvite": send_invite,
+            "email": email,
+        }
 
         # Remove empty args in dictionary
         agent = json_format.remove_empty_keys(agent)
 
-        logger.info(f'Generating {full_name} agent.')
-        return self._request(f'groups/{group_id}/agents', req_type="POST", payload=agent)
+        logger.info(f"Generating {full_name} agent.")
+        return self._request(
+            f"groups/{group_id}/agents", req_type="POST", payload=agent
+        )
 
     def update_agent(self, agent_id, name=None, full_name=None, send_invite=False):
         """
@@ -201,15 +213,13 @@ class Hustle(object):
             dict
         """
 
-        agent = {'name': name,
-                 'fullName': full_name,
-                 'sendInvite': send_invite}
+        agent = {"name": name, "fullName": full_name, "sendInvite": send_invite}
 
         # Remove empty args in dictionary
         agent = json_format.remove_empty_keys(agent)
 
-        logger.info(f'Updating agent {agent_id}.')
-        return self._request(f'agents/{agent_id}', req_type="PUT", payload=agent)
+        logger.info(f"Updating agent {agent_id}.")
+        return self._request(f"agents/{agent_id}", req_type="PUT", payload=agent)
 
     def get_organizations(self):
         """
@@ -220,8 +230,8 @@ class Hustle(object):
                 See :ref:`parsons-table` for output options.
         """
 
-        tbl = Table(self._request('organizations'))
-        logger.info(f'Got {tbl.num_rows} organizations.')
+        tbl = Table(self._request("organizations"))
+        logger.info(f"Got {tbl.num_rows} organizations.")
         return tbl
 
     def get_organization(self, organization_id):
@@ -235,8 +245,8 @@ class Hustle(object):
             dict
         """
 
-        r = self._request(f'organizations/{organization_id}')
-        logger.info(f'Got {organization_id} organization.')
+        r = self._request(f"organizations/{organization_id}")
+        logger.info(f"Got {organization_id} organization.")
         return r
 
     def get_groups(self, organization_id):
@@ -250,8 +260,8 @@ class Hustle(object):
                 See :ref:`parsons-table` for output options.
         """
 
-        tbl = Table(self._request(f'organizations/{organization_id}/groups'))
-        logger.info(f'Got {tbl.num_rows} groups.')
+        tbl = Table(self._request(f"organizations/{organization_id}/groups"))
+        logger.info(f"Got {tbl.num_rows} groups.")
         return tbl
 
     def get_group(self, group_id):
@@ -263,8 +273,8 @@ class Hustle(object):
                 The group id.
         """
 
-        r = self._request(f'groups/{group_id}')
-        logger.info(f'Got {group_id} group.')
+        r = self._request(f"groups/{group_id}")
+        logger.info(f"Got {group_id} group.")
         return r
 
     def get_lead(self, lead_id):
@@ -278,8 +288,8 @@ class Hustle(object):
             dict
         """
 
-        r = self._request(f'leads/{lead_id}')
-        logger.info(f'Got {lead_id} lead.')
+        r = self._request(f"leads/{lead_id}")
+        logger.info(f"Got {lead_id} lead.")
         return r
 
     def get_leads(self, organization_id=None, group_id=None):
@@ -298,24 +308,36 @@ class Hustle(object):
         """
 
         if organization_id is None and group_id is None:
-            raise ValueError('Either organization_id or group_id required.')
+            raise ValueError("Either organization_id or group_id required.")
 
         if organization_id is not None and group_id is not None:
-            raise ValueError('Only one of organization_id and group_id may be populated.')
+            raise ValueError(
+                "Only one of organization_id and group_id may be populated."
+            )
 
         if organization_id:
-            endpoint = f'organizations/{organization_id}/leads'
-            logger.info(f'Retrieving {organization_id} organization leads.')
+            endpoint = f"organizations/{organization_id}/leads"
+            logger.info(f"Retrieving {organization_id} organization leads.")
         if group_id:
-            endpoint = f'groups/{group_id}/leads'
-            logger.info(f'Retrieving {group_id} group leads.')
+            endpoint = f"groups/{group_id}/leads"
+            logger.info(f"Retrieving {group_id} group leads.")
 
         tbl = Table(self._request(endpoint))
-        logger.info(f'Got {tbl.num_rows} leads.')
+        logger.info(f"Got {tbl.num_rows} leads.")
         return tbl
 
-    def create_lead(self, group_id, phone_number, first_name, last_name=None, email=None,
-                    notes=None, follow_up=None, custom_fields=None, tag_ids=None):
+    def create_lead(
+        self,
+        group_id,
+        phone_number,
+        first_name,
+        last_name=None,
+        email=None,
+        notes=None,
+        follow_up=None,
+        custom_fields=None,
+        tag_ids=None,
+    ):
         """
 
         Create a lead.
@@ -344,20 +366,21 @@ class Hustle(object):
                 ``None``
         """
 
-        lead = {'firstName': first_name,
-                'lastName': last_name,
-                'email': email,
-                'phoneNumber': phone_number,
-                'notes': notes,
-                'followUp': follow_up,
-                'customFields': custom_fields,
-                'tagIds': tag_ids
-                }
+        lead = {
+            "firstName": first_name,
+            "lastName": last_name,
+            "email": email,
+            "phoneNumber": phone_number,
+            "notes": notes,
+            "followUp": follow_up,
+            "customFields": custom_fields,
+            "tagIds": tag_ids,
+        }
 
         # Remove empty args in dictionary
         lead = json_format.remove_empty_keys(lead)
-        logger.info(f'Generating lead for {first_name} {last_name}.')
-        return self._request(f'groups/{group_id}/leads', req_type="POST", payload=lead)
+        logger.info(f"Generating lead for {first_name} {last_name}.")
+        return self._request(f"groups/{group_id}/leads", req_type="POST", payload=lead)
 
     def create_leads(self, table, group_id=None):
         """
@@ -394,14 +417,21 @@ class Hustle(object):
 
         table.map_columns(LEAD_COLUMN_MAP)
 
-        arg_list = ['first_name', 'last_name', 'email', 'phone_number', 'follow_up',
-                    'tag_ids', 'group_id']
+        arg_list = [
+            "first_name",
+            "last_name",
+            "email",
+            "phone_number",
+            "follow_up",
+            "tag_ids",
+            "group_id",
+        ]
 
         created_leads = []
 
         for row in table:
 
-            lead = {'group_id': group_id}
+            lead = {"group_id": group_id}
             custom_fields = {}
 
             # Check for column names that map to arguments, if not assign
@@ -412,21 +442,32 @@ class Hustle(object):
                 else:
                     custom_fields[k] = v
 
-            lead['custom_fields'] = custom_fields
+            lead["custom_fields"] = custom_fields
 
             # Group Id check
-            if not group_id and 'group_id' not in table.columns:
-                raise ValueError('Group Id must be passed as an argument or a column value.')
+            if not group_id and "group_id" not in table.columns:
+                raise ValueError(
+                    "Group Id must be passed as an argument or a column value."
+                )
             if group_id:
-                lead['group_id'] = group_id
+                lead["group_id"] = group_id
 
             created_leads.append(self.create_lead(**lead))
 
         logger.info(f"Created {table.num_rows} leads.")
         return Table(created_leads)
 
-    def update_lead(self, lead_id, first_name=None, last_name=None, email=None,
-                    global_opt_out=None, notes=None, follow_up=None, tag_ids=None):
+    def update_lead(
+        self,
+        lead_id,
+        first_name=None,
+        last_name=None,
+        email=None,
+        global_opt_out=None,
+        notes=None,
+        follow_up=None,
+        tag_ids=None,
+    ):
         """
         Update a lead.
 
@@ -451,20 +492,22 @@ class Hustle(object):
             dict
         """
 
-        lead = {'leadId': lead_id,
-                'firstName': first_name,
-                'lastName': last_name,
-                'email': email,
-                'globalOptedOut': global_opt_out,
-                'notes': notes,
-                'followUp': follow_up,
-                'tagIds': tag_ids}
+        lead = {
+            "leadId": lead_id,
+            "firstName": first_name,
+            "lastName": last_name,
+            "email": email,
+            "globalOptedOut": global_opt_out,
+            "notes": notes,
+            "followUp": follow_up,
+            "tagIds": tag_ids,
+        }
 
         # Remove empty args in dictionary
         lead = json_format.remove_empty_keys(lead)
 
-        logger.info(f'Updating lead for {first_name} {last_name}.')
-        return self._request(f'leads/{lead_id}', req_type="PUT", payload=lead)
+        logger.info(f"Updating lead for {first_name} {last_name}.")
+        return self._request(f"leads/{lead_id}", req_type="PUT", payload=lead)
 
     def get_tags(self, organization_id):
         """
@@ -478,8 +521,8 @@ class Hustle(object):
                 See :ref:`parsons-table` for output options.
         """
 
-        tbl = Table(self._request(f'organizations/{organization_id}/tags'))
-        logger.info(f'Got {tbl.num_rows} tags for {organization_id} organization.')
+        tbl = Table(self._request(f"organizations/{organization_id}/tags"))
+        logger.info(f"Got {tbl.num_rows} tags for {organization_id} organization.")
         return tbl
 
     def get_tag(self, tag_id):
@@ -493,6 +536,6 @@ class Hustle(object):
             dict
         """
 
-        r = self._request(f'tags/{tag_id}')
-        logger.info(f'Got {tag_id} tag.')
+        r = self._request(f"tags/{tag_id}")
+        logger.info(f"Got {tag_id} tag.")
         return r
