@@ -1,5 +1,3 @@
 from parsons.mailchimp.mailchimp import Mailchimp
 
-__all__ = [
-    'Mailchimp'
-]
+__all__ = ["Mailchimp"]
