@@ -7,7 +7,7 @@ from parsons.utilities.api_connector import APIConnector
 logger = logging.getLogger(__name__)
 
 
-class Mailchimp():
+class Mailchimp:
     """
     Instantiate Mailchimp Class
 
@@ -20,16 +20,25 @@ class Mailchimp():
     """
 
     def __init__(self, api_key=None):
-        self.api_key = check_env.check('MAILCHIMP_API_KEY', api_key)
+        self.api_key = check_env.check("MAILCHIMP_API_KEY", api_key)
         self.domain = re.findall("(?<=-).+$", self.api_key)[0]
-        self.uri = f'https://{self.domain}.api.mailchimp.com/3.0/'
-        self.client = APIConnector(self.uri, auth=('x', self.api_key))
+        self.uri = f"https://{self.domain}.api.mailchimp.com/3.0/"
+        self.client = APIConnector(self.uri, auth=("x", self.api_key))
 
-    def get_lists(self, fields=None, exclude_fields=None,
-                  count=None, offset=None, before_date_created=None,
-                  since_date_created=None, before_campaign_last_sent=None,
-                  since_campaign_last_sent=None, email=None, sort_field=None,
-                  sort_dir=None):
+    def get_lists(
+        self,
+        fields=None,
+        exclude_fields=None,
+        count=None,
+        offset=None,
+        before_date_created=None,
+        since_date_created=None,
+        before_campaign_last_sent=None,
+        since_campaign_last_sent=None,
+        email=None,
+        sort_field=None,
+        sort_dir=None,
+    ):
         """
         Get a table of lists under the account based on query parameters. Note
         that argument descriptions here are sourced from Mailchimp's official
@@ -74,32 +83,46 @@ class Mailchimp():
         `Returns:`
             Table Class
         """
-        params = {'fields': fields,
-                  'exclude_fields': exclude_fields,
-                  'count': count,
-                  'offset': offset,
-                  'before_date_created': before_date_created,
-                  'since_date_created': since_date_created,
-                  'before_campaign_last_sent': before_campaign_last_sent,
-                  'since_campaign_last_sent': since_campaign_last_sent,
-                  'email': email,
-                  'sort_field': sort_field,
-                  'sort_dir': sort_dir}
+        params = {
+            "fields": fields,
+            "exclude_fields": exclude_fields,
+            "count": count,
+            "offset": offset,
+            "before_date_created": before_date_created,
+            "since_date_created": since_date_created,
+            "before_campaign_last_sent": before_campaign_last_sent,
+            "since_campaign_last_sent": since_campaign_last_sent,
+            "email": email,
+            "sort_field": sort_field,
+            "sort_dir": sort_dir,
+        }
 
-        response = self.client.get_request('lists', params=params)
-        tbl = Table(response['lists'])
-        logger.info(f'Found {tbl.num_rows} lists.')
+        response = self.client.get_request("lists", params=params)
+        tbl = Table(response["lists"])
+        logger.info(f"Found {tbl.num_rows} lists.")
         if tbl.num_rows > 0:
             return tbl
         else:
             return Table()
 
-    def get_campaigns(self, fields=None, exclude_fields=None,
-                      count=None, offset=None, type=None, status=None,
-                      before_send_time=None, since_send_time=None,
-                      before_create_time=None, since_create_time=None,
-                      list_id=None, folder_id=None, member_id=None,
-                      sort_field=None, sort_dir=None):
+    def get_campaigns(
+        self,
+        fields=None,
+        exclude_fields=None,
+        count=None,
+        offset=None,
+        type=None,
+        status=None,
+        before_send_time=None,
+        since_send_time=None,
+        before_create_time=None,
+        since_create_time=None,
+        list_id=None,
+        folder_id=None,
+        member_id=None,
+        sort_field=None,
+        sort_dir=None,
+    ):
         """
         Get a table of campaigns under the account based on query parameters.
         Note that argument descriptions here are sourced from Mailchimp's
@@ -153,39 +176,55 @@ class Mailchimp():
         `Returns:`
             Table Class
         """
-        params = {'fields': fields,
-                  'exclude_fields': exclude_fields,
-                  'count': count,
-                  'offset': offset,
-                  'type': type,
-                  'status': status,
-                  'before_send_time': before_send_time,
-                  'since_send_time': since_send_time,
-                  'before_create_time': before_create_time,
-                  'since_create_time': since_create_time,
-                  'list_id': list_id,
-                  'folder_id': folder_id,
-                  'member_id': member_id,
-                  'sort_field': sort_field,
-                  'sort_dir': sort_dir}
+        params = {
+            "fields": fields,
+            "exclude_fields": exclude_fields,
+            "count": count,
+            "offset": offset,
+            "type": type,
+            "status": status,
+            "before_send_time": before_send_time,
+            "since_send_time": since_send_time,
+            "before_create_time": before_create_time,
+            "since_create_time": since_create_time,
+            "list_id": list_id,
+            "folder_id": folder_id,
+            "member_id": member_id,
+            "sort_field": sort_field,
+            "sort_dir": sort_dir,
+        }
 
-        response = self.client.get_request('campaigns', params=params)
-        tbl = Table(response['campaigns'])
-        logger.info(f'Found {tbl.num_rows} campaigns.')
+        response = self.client.get_request("campaigns", params=params)
+        tbl = Table(response["campaigns"])
+        logger.info(f"Found {tbl.num_rows} campaigns.")
         if tbl.num_rows > 0:
             return tbl
         else:
             return Table()
 
-    def get_members(self, list_id, fields=None,
-                    exclude_fields=None, count=None, offset=None,
-                    email_type=None, status=None, since_timestamp_opt=None,
-                    before_timestamp_opt=None, since_last_changed=None,
-                    before_last_changed=None, unique_email_id=None,
-                    vip_only=False, interest_category_id=None,
-                    interest_ids=None, interest_match=None, sort_field=None,
-                    sort_dir=None, since_last_campaign=None,
-                    unsubscribed_since=None):
+    def get_members(
+        self,
+        list_id,
+        fields=None,
+        exclude_fields=None,
+        count=None,
+        offset=None,
+        email_type=None,
+        status=None,
+        since_timestamp_opt=None,
+        before_timestamp_opt=None,
+        since_last_changed=None,
+        before_last_changed=None,
+        unique_email_id=None,
+        vip_only=False,
+        interest_category_id=None,
+        interest_ids=None,
+        interest_match=None,
+        sort_field=None,
+        sort_dir=None,
+        since_last_campaign=None,
+        unsubscribed_since=None,
+    ):
         """
         Get a table of members in a list based on query parameters. Note that
         argument descriptions here are sourced from Mailchimp's official API
@@ -266,37 +305,45 @@ class Mailchimp():
         `Returns:`
             Table Class
         """
-        params = {'fields': fields,
-                  'exclude_fields': exclude_fields,
-                  'count': count,
-                  'offset': offset,
-                  'email_type': email_type,
-                  'status': status,
-                  'since_timestamp_opt': since_timestamp_opt,
-                  'before_timestamp_opt': before_timestamp_opt,
-                  'since_last_changed': since_last_changed,
-                  'before_last_changed': before_last_changed,
-                  'unqiue_email_id': unique_email_id,
-                  'vip_only': vip_only,
-                  'interest_category_id': interest_category_id,
-                  'interest_ids': interest_ids,
-                  'interest_match': interest_match,
-                  'sort_field': sort_field,
-                  'sort_dir': sort_dir,
-                  'since_last_campaign': since_last_campaign,
-                  'unsubscribed_since': unsubscribed_since}
+        params = {
+            "fields": fields,
+            "exclude_fields": exclude_fields,
+            "count": count,
+            "offset": offset,
+            "email_type": email_type,
+            "status": status,
+            "since_timestamp_opt": since_timestamp_opt,
+            "before_timestamp_opt": before_timestamp_opt,
+            "since_last_changed": since_last_changed,
+            "before_last_changed": before_last_changed,
+            "unqiue_email_id": unique_email_id,
+            "vip_only": vip_only,
+            "interest_category_id": interest_category_id,
+            "interest_ids": interest_ids,
+            "interest_match": interest_match,
+            "sort_field": sort_field,
+            "sort_dir": sort_dir,
+            "since_last_campaign": since_last_campaign,
+            "unsubscribed_since": unsubscribed_since,
+        }
 
-        response = self.client.get_request(f'lists/{list_id}/members', params=params)
-        tbl = Table(response['members'])
-        logger.info(f'Found {tbl.num_rows} members.')
+        response = self.client.get_request(f"lists/{list_id}/members", params=params)
+        tbl = Table(response["members"])
+        logger.info(f"Found {tbl.num_rows} members.")
         if tbl.num_rows > 0:
             return tbl
         else:
             return Table()
 
-    def get_campaign_emails(self, campaign_id, fields=None,
-                            exclude_fields=None, count=None, offset=None,
-                            since=None):
+    def get_campaign_emails(
+        self,
+        campaign_id,
+        fields=None,
+        exclude_fields=None,
+        count=None,
+        offset=None,
+        since=None,
+    ):
         """
         Get a table of individual emails from a campaign based on query
         parameters. Note that argument descriptions here are sourced from
@@ -326,22 +373,26 @@ class Mailchimp():
         `Returns:`
             Table Class
         """
-        params = {'fields': fields,
-                  'exclude_fields': exclude_fields,
-                  'count': count,
-                  'offset': offset,
-                  'since': since}
+        params = {
+            "fields": fields,
+            "exclude_fields": exclude_fields,
+            "count": count,
+            "offset": offset,
+            "since": since,
+        }
 
-        response = self.client.get_request(f'reports/{campaign_id}/email-activity',
-                                           params=params)
-        tbl = Table(response['emails'])
+        response = self.client.get_request(
+            f"reports/{campaign_id}/email-activity", params=params
+        )
+        tbl = Table(response["emails"])
         if tbl.num_rows > 0:
             return tbl
         else:
             return Table()
 
-    def get_unsubscribes(self, campaign_id, fields=None,
-                         exclude_fields=None, count=None, offset=None):
+    def get_unsubscribes(
+        self, campaign_id, fields=None, exclude_fields=None, count=None, offset=None
+    ):
         """
         Get a table of unsubscribes associated with a campaign based on query
         parameters. Note that argument descriptions here are sourced from
@@ -367,15 +418,18 @@ class Mailchimp():
         `Returns:`
             Table Class
         """
-        params = {'fields': fields,
-                  'exclude_fields': exclude_fields,
-                  'count': count,
-                  'offset': offset}
+        params = {
+            "fields": fields,
+            "exclude_fields": exclude_fields,
+            "count": count,
+            "offset": offset,
+        }
 
-        response = self.client.get_request(f'reports/{campaign_id}/unsubscribed',
-                                           params=params)
-        tbl = Table(response['unsubscribes'])
-        logger.info(f'Found {tbl.num_rows} unsubscribes for {campaign_id}.')
+        response = self.client.get_request(
+            f"reports/{campaign_id}/unsubscribed", params=params
+        )
+        tbl = Table(response["unsubscribes"])
+        logger.info(f"Found {tbl.num_rows} unsubscribes for {campaign_id}.")
         if tbl.num_rows > 0:
             return tbl
         else:
