@@ -1,5 +1,3 @@
 from parsons.mobilize_america.ma import MobilizeAmerica
 
-__all__ = [
-    'MobilizeAmerica'
-]
+__all__ = ["MobilizeAmerica"]
