@@ -1,5 +1,3 @@
 from parsons.newmode.newmode import Newmode
 
-__all__ = [
-    'Newmode'
-]
+__all__ = ["Newmode"]
