@@ -1,5 +1,3 @@
 from parsons.ngpvan.van import VAN
 
-__all__ = [
-    'VAN'
-]
+__all__ = ["VAN"]
