@@ -4,13 +4,12 @@ import logging
 logger = logging.getLogger(__name__)
 
 
-class CustomFields():
-
+class CustomFields:
     def __init__(self, van_connection):
 
         self.connection = van_connection
 
-    def get_custom_fields(self, field_type='contacts'):
+    def get_custom_fields(self, field_type="contacts"):
         """
         Get custom fields.
 
@@ -23,13 +22,13 @@ class CustomFields():
                 See :ref:`parsons-table` for output options.
         """
 
-        params = {'customFieldsGroupType': field_type.capitalize()}
+        params = {"customFieldsGroupType": field_type.capitalize()}
 
-        tbl = Table(self.connection.get_request('customFields', params=params))
-        logger.info(f'Found {tbl.num_rows} custom fields.')
+        tbl = Table(self.connection.get_request("customFields", params=params))
+        logger.info(f"Found {tbl.num_rows} custom fields.")
         return tbl
 
-    def get_custom_fields_values(self, field_type='contacts'):
+    def get_custom_fields_values(self, field_type="contacts"):
         """
         Get custom field values as a long table.
 
@@ -46,16 +45,22 @@ class CustomFields():
 
         # Some custom fields do no have associated values. If this is the case then
         # we should return an empty Table, but with the expected columns.
-        if tbl.get_column_types('availableValues') == ['NoneType']:
-            logger.info('Found 0 custom field values.')
-            return Table([{'customFieldId': None,
-                           'id': None,
-                           'name': None,
-                           'parentValueId': None}])
+        if tbl.get_column_types("availableValues") == ["NoneType"]:
+            logger.info("Found 0 custom field values.")
+            return Table(
+                [
+                    {
+                        "customFieldId": None,
+                        "id": None,
+                        "name": None,
+                        "parentValueId": None,
+                    }
+                ]
+            )
 
         else:
-            logger.info(f'Found {tbl.num_rows} custom field values.')
-            return tbl.long_table('customFieldId', 'availableValues', prepend=False)
+            logger.info(f"Found {tbl.num_rows} custom field values.")
+            return tbl.long_table("customFieldId", "availableValues", prepend=False)
 
     def get_custom_field(self, custom_field_id):
         """
@@ -68,6 +73,6 @@ class CustomFields():
             A json.
         """
 
-        r = self.connection.get_request(f'customFields/{custom_field_id}')
-        logger.info(f'Found custom field {custom_field_id}.')
+        r = self.connection.get_request(f"customFields/{custom_field_id}")
+        logger.info(f"Found custom field {custom_field_id}.")
         return r
