@@ -7,7 +7,6 @@ logger = logging.getLogger(__name__)
 
 
 class Locations(object):
-
     def __init__(self, van_connection):
 
         self.connection = van_connection
@@ -22,10 +21,10 @@ class Locations(object):
         `Returns:`
             Parsons Table
                 See :ref:`parsons-table` for output options.
-         """
+        """
 
-        tbl = Table(self.connection.get_request('locations', params={'name': name}))
-        logger.info(f'Found {tbl.num_rows} locations.')
+        tbl = Table(self.connection.get_request("locations", params={"name": name}))
+        logger.info(f"Found {tbl.num_rows} locations.")
         return self._unpack_loc(tbl)
 
     def get_location(self, location_id):
@@ -39,12 +38,19 @@ class Locations(object):
             dict
         """
 
-        r = self.connection.get_request(f'locations/{location_id}')
-        logger.info(f'Found location {location_id}.')
+        r = self.connection.get_request(f"locations/{location_id}")
+        logger.info(f"Found location {location_id}.")
         return r
 
-    def create_location(self, name, address_line1=None, address_line2=None, city=None,
-                        state=None, zip_code=None):
+    def create_location(
+        self,
+        name,
+        address_line1=None,
+        address_line2=None,
+        city=None,
+        state=None,
+        zip_code=None,
+    ):
         """
         Find or create a location. If location already exists, will return location id.
 
@@ -66,17 +72,19 @@ class Locations(object):
                     A location id.
         """
 
-        location = {'name': name,
-                    'address': {
-                        'addressLine1': address_line1,
-                        'addressLine2': address_line2,
-                        'city': city,
-                        'stateOrProvince': state,
-                        'zipOrPostalCode': zip_code
-                    }}
+        location = {
+            "name": name,
+            "address": {
+                "addressLine1": address_line1,
+                "addressLine2": address_line2,
+                "city": city,
+                "stateOrProvince": state,
+                "zipOrPostalCode": zip_code,
+            },
+        }
 
-        r = self.connection.post_request('locations/findOrCreate', json=location)
-        logger.info(f'Location {r} created.')
+        r = self.connection.post_request("locations/findOrCreate", json=location)
+        logger.info(f"Location {r} created.")
         return r
 
     def delete_location(self, location_id):
@@ -90,8 +98,8 @@ class Locations(object):
             ``None``
         """
 
-        r = self.connection.delete_request(f'locations/{location_id}')
-        logger.info(f'Location {location_id} deleted.')
+        r = self.connection.delete_request(f"locations/{location_id}")
+        logger.info(f"Location {location_id} deleted.")
         return r
 
     def _unpack_loc(self, table):
@@ -100,10 +108,10 @@ class Locations(object):
         if isinstance(table, tuple):
             return table
 
-        if 'address' in table.columns:
-            table.unpack_dict('address', prepend=False)
+        if "address" in table.columns:
+            table.unpack_dict("address", prepend=False)
 
-        if 'geoLocation' in table.columns:
-            table.unpack_dict('geoLocation', prepend=False)
+        if "geoLocation" in table.columns:
+            table.unpack_dict("geoLocation", prepend=False)
 
         return table
