@@ -12,7 +12,6 @@ class TargetsFailed(Exception):
 
 
 class Targets(object):
-
     def __init__(self, van_connection):
 
         self.connection = van_connection
@@ -29,8 +28,8 @@ class Targets(object):
                 See :ref:`parsons-table` for output options.
         """
 
-        tbl = Table(self.connection.get_request('targets'))
-        logger.info(f'Found {tbl.num_rows} targets.')
+        tbl = Table(self.connection.get_request("targets"))
+        logger.info(f"Found {tbl.num_rows} targets.")
         return tbl
 
     def get_target(self, target_id):
@@ -45,8 +44,8 @@ class Targets(object):
                 The target
         """
 
-        r = self.connection.get_request(f'targets/{target_id}')
-        logger.info(f'Found target {target_id}.')
+        r = self.connection.get_request(f"targets/{target_id}")
+        logger.info(f"Found target {target_id}.")
         return r
 
     def get_target_export(self, export_job_id):
@@ -58,15 +57,17 @@ class Targets(object):
                 See :ref:`parsons-table` for output options.
         """
 
-        response = self.connection.get_request(f'targetExportJobs/{export_job_id}')
-        job_status = response.get('jobStatus')
-        if job_status == 'Complete':
-            url = response['file']['downloadUrl']
+        response = self.connection.get_request(f"targetExportJobs/{export_job_id}")
+        job_status = response.get("jobStatus")
+        if job_status == "Complete":
+            url = response["file"]["downloadUrl"]
             return Table(petl.fromcsv(url, encoding="utf-8-sig"))
-        elif job_status == 'Pending' or job_status == 'InProcess':
-            logger.info(f'Target export job is pending or in process for {export_job_id}.')
+        elif job_status == "Pending" or job_status == "InProcess":
+            logger.info(
+                f"Target export job is pending or in process for {export_job_id}."
+            )
         else:
-            raise TargetsFailed(f'Target export failed for {export_job_id}')
+            raise TargetsFailed(f"Target export failed for {export_job_id}")
 
     def create_target_export(self, target_id, webhook_url=None):
         """
@@ -79,10 +80,8 @@ class Targets(object):
             dict
                 The target export job ID
         """
-        target_export = {
-                        'targetId': target_id
-                        }
+        target_export = {"targetId": target_id}
 
-        r = self.connection.post_request('targetExportJobs', json=target_export)
-        logger.info(f'Created new target export job for {target_id}.')
+        r = self.connection.post_request("targetExportJobs", json=target_export)
+        logger.info(f"Created new target export job for {target_id}.")
         return r
