@@ -1,5 +1,3 @@
-
-
 def action_parse(action):
     """
     Internal method to parse and validate actions, which are required for some methods
@@ -8,7 +6,7 @@ def action_parse(action):
 
     action = action.capitalize()
 
-    if action not in ('Apply', 'Remove'):
+    if action not in ("Apply", "Remove"):
 
         raise ValueError("Action must be either 'Apply' or 'Remove'")
 
@@ -21,6 +19,6 @@ def list_to_string(string_arg):
     """
 
     if string_arg:
-        return '.'.join(string_arg)
+        return ".".join(string_arg)
     else:
         return string_arg
