@@ -5,31 +5,36 @@ from parsons.utilities.api_connector import APIConnector
 
 logger = logging.getLogger(__name__)
 
-URI = 'https://api.securevan.com/v4/'
-SOAP_URI = 'https://api.securevan.com/Services/V3/ListService.asmx?WSDL'
+URI = "https://api.securevan.com/v4/"
+SOAP_URI = "https://api.securevan.com/Services/V3/ListService.asmx?WSDL"
 
 
 class VANConnector(object):
+    def __init__(self, api_key=None, auth_name="default", db=None):
 
-    def __init__(self, api_key=None, auth_name='default', db=None):
+        self.api_key = check_env.check("VAN_API_KEY", api_key)
 
-        self.api_key = check_env.check('VAN_API_KEY', api_key)
-
-        if db == 'MyVoters':
+        if db == "MyVoters":
             self.db_code = 0
-        elif db in ['MyMembers', 'MyCampaign', 'EveryAction']:
+        elif db in ["MyMembers", "MyCampaign", "EveryAction"]:
             self.db_code = 1
         else:
-            raise KeyError('Invalid database type specified. Pick one of:'
-                           ' MyVoters, MyCampaign, MyMembers, EveryAction.')
+            raise KeyError(
+                "Invalid database type specified. Pick one of:"
+                " MyVoters, MyCampaign, MyMembers, EveryAction."
+            )
 
         self.uri = URI
         self.db = db
         self.auth_name = auth_name
-        self.pagination_key = 'nextPageLink'
-        self.auth = (self.auth_name, self.api_key + '|' + str(self.db_code))
-        self.api = APIConnector(self.uri, auth=self.auth, data_key='items',
-                                pagination_key=self.pagination_key)
+        self.pagination_key = "nextPageLink"
+        self.auth = (self.auth_name, self.api_key + "|" + str(self.db_code))
+        self.api = APIConnector(
+            self.uri,
+            auth=self.auth,
+            data_key="items",
+            pagination_key=self.pagination_key,
+        )
 
         # We will not create the SOAP client unless we need to as this triggers checking for
         # valid credentials. As not all API keys are provisioned for SOAP, this keeps it from
@@ -42,7 +47,7 @@ class VANConnector(object):
         Returns the API key profile with includes permissions and other metadata.
         """
 
-        return self.get_request('apiKeyProfiles')[0]
+        return self.get_request("apiKeyProfiles")[0]
 
     @property
     def soap_client(self):
@@ -50,7 +55,12 @@ class VANConnector(object):
         if not self._soap_client:
 
             # Create the SOAP client
-            soap_auth = {'Header': {'DatabaseMode': self.soap_client_db(), 'APIKey': self.api_key}}
+            soap_auth = {
+                "Header": {
+                    "DatabaseMode": self.soap_client_db(),
+                    "APIKey": self.api_key,
+                }
+            }
             self._soap_client = Client(SOAP_URI, soapheaders=soap_auth)
 
         return self._soap_client
@@ -60,10 +70,10 @@ class VANConnector(object):
         Parse the REST database name to the accepted SOAP format
         """
 
-        if self.db == 'MyVoters':
-            return 'MyVoterFile'
-        if self.db == 'EveryAction':
-            return 'MyCampaign'
+        if self.db == "MyVoters":
+            return "MyVoterFile"
+        if self.db == "EveryAction":
+            return "MyCampaign"
         else:
             return self.db
 
@@ -74,9 +84,9 @@ class VANConnector(object):
 
         # Paginate
         while isinstance(r, dict) and self.api.next_page_check_url(r):
-            if endpoint == 'savedLists' and not r['items']:
+            if endpoint == "savedLists" and not r["items"]:
                 break
-            if endpoint == 'printedLists' and not r['items']:
+            if endpoint == "printedLists" and not r["items"]:
                 break
             r = self.api.get_request(r[self.pagination_key], **kwargs)
             data.extend(self.api.data_parse(r))
