@@ -1,5 +1,3 @@
 from parsons.pdi.pdi import PDI
 
-__all__ = [
-    'PDI'
-]
+__all__ = ["PDI"]
