@@ -1,5 +1,3 @@
 from parsons.quickbase.quickbase import Quickbase
 
-__all__ = [
-    'Quickbase'
-]
+__all__ = ["Quickbase"]
