@@ -1,5 +1,3 @@
 from parsons.redash.redash import Redash
 
-__all__ = [
-    'Redash'
-]
+__all__ = ["Redash"]
