@@ -1,5 +1,3 @@
 from parsons.salesforce.salesforce import Salesforce
 
-__all__ = [
-    'Salesforce'
-]
+__all__ = ["Salesforce"]
