@@ -1,5 +1,3 @@
 from parsons.scytl.scytl import Scytl
 
-__all__ = [
-    'Scytl'
-]
+__all__ = ["Scytl"]
