@@ -1,5 +1,3 @@
 from parsons.sftp.sftp import SFTP
 
-__all__ = [
-    'SFTP'
-]
+__all__ = ["SFTP"]
