@@ -5,7 +5,7 @@ import paramiko
 def connection_exists(args, kwargs):
     if any([isinstance(arg, paramiko.sftp_client.SFTPClient) for arg in args]):
         return True
-    if 'connection' in kwargs and kwargs['connection']:
+    if "connection" in kwargs and kwargs["connection"]:
         return True
     return False
 
@@ -15,7 +15,7 @@ def connect(func):
     def wrapper(*args, **kwargs):
         if not connection_exists(args, kwargs):
             with args[0].create_connection() as connection:
-                kwargs['connection'] = connection
+                kwargs["connection"] = connection
                 return func(*args, **kwargs)
         else:
             return func(*args, **kwargs)
