@@ -1,5 +1,3 @@
 from parsons.shopify.shopify import Shopify
 
-__all__ = [
-    'Shopify'
-]
+__all__ = ["Shopify"]
