@@ -1,5 +1,3 @@
 from parsons.sisense.sisense import Sisense
 
-__all__ = [
-    'Sisense'
-]
+__all__ = ["Sisense"]
