@@ -1,7 +1,4 @@
 from parsons.targetsmart.targetsmart_api import TargetSmartAPI
 from parsons.targetsmart.targetsmart_automation import TargetSmartAutomation
 
-__all__ = [
-    'TargetSmartAPI',
-    'TargetSmartAutomation'
-]
+__all__ = ["TargetSmartAPI", "TargetSmartAutomation"]
