@@ -1,5 +1,3 @@
 from parsons.turbovote.turbovote import TurboVote
 
-__all__ = [
-    'TurboVote'
-]
+__all__ = ["TurboVote"]
