@@ -5,7 +5,7 @@ from parsons.utilities import check_env
 
 logger = logging.getLogger(__name__)
 
-TURBOVOTE_URI = 'https://turbovote-admin-http-api.prod.democracy.works/'
+TURBOVOTE_URI = "https://turbovote-admin-http-api.prod.democracy.works/"
 
 
 class TurboVote(object):
@@ -28,22 +28,21 @@ class TurboVote(object):
 
     def __init__(self, username=None, password=None, subdomain=None):
 
-        self.username = check_env.check('TURBOVOTE_USERNAME', username)
-        self.password = check_env.check('TURBOVOTE_PASSWORD', password)
-        self.subdomain = check_env.check('TURBOVOTE_SUBDOMAIN', subdomain)
+        self.username = check_env.check("TURBOVOTE_USERNAME", username)
+        self.password = check_env.check("TURBOVOTE_PASSWORD", password)
+        self.subdomain = check_env.check("TURBOVOTE_SUBDOMAIN", subdomain)
         self.uri = TURBOVOTE_URI
 
     def _get_token(self):
         # Retrieve a temporary bearer token to access API
 
-        url = self.uri + 'login'
-        payload = {'username': self.username,
-                   'password': self.password}
+        url = self.uri + "login"
+        payload = {"username": self.username, "password": self.password}
         r = requests.post(url, data=payload)
         logger.debug(r.url)
         r.raise_for_status()
 
-        return r.json()['id-token']
+        return r.json()["id-token"]
 
     def get_users(self):
         """
@@ -54,13 +53,13 @@ class TurboVote(object):
                 See :ref:`parsons-table` for output options.
         """
 
-        url = self.uri + f'partners/{self.subdomain}.turbovote.org/users'
+        url = self.uri + f"partners/{self.subdomain}.turbovote.org/users"
 
         headers = {"Authorization": f"Bearer {self._get_token()}"}
         r = requests.get(url, headers=headers)
         logger.debug(r)
         r.raise_for_status()
         tbl = Table.from_csv_string(r.text)
-        logger.info(f'{tbl.num_rows} users retrieved.')
+        logger.info(f"{tbl.num_rows} users retrieved.")
 
         return tbl
