@@ -1,5 +1,3 @@
 from parsons.twilio.twilio import Twilio
 
-__all__ = [
-    'Twilio'
-]
+__all__ = ["Twilio"]
