@@ -1,5 +1,3 @@
 from parsons.zoom.zoom import Zoom
 
-__all__ = [
-    'Zoom'
-]
+__all__ = ["Zoom"]
