@@ -5,9 +5,10 @@ from parsons import CivisClient, Table
 # from . import scratch_creds
 
 
-@unittest.skipIf(not os.environ.get('LIVE_TEST'), 'Skipping because not running live test')
+@unittest.skipIf(
+    not os.environ.get("LIVE_TEST"), "Skipping because not running live test"
+)
 class TestCivisClient(unittest.TestCase):
-
     def setUp(self):
 
         self.civis = CivisClient()
@@ -18,7 +19,7 @@ class TestCivisClient(unittest.TestCase):
                     create schema test_parsons;
                     """
 
-        self.lst_dicts = [{'first': 'Bob', 'last': 'Smith'}]
+        self.lst_dicts = [{"first": "Bob", "last": "Smith"}]
         self.tbl = Table(self.lst_dicts)
 
         self.civis.query(setup_sql)
@@ -35,16 +36,16 @@ class TestCivisClient(unittest.TestCase):
     def test_table_import_query(self):
 
         # Test that a good table imports correctly
-        self.civis.table_import(self.tbl, 'test_parsons.test_table')
+        self.civis.table_import(self.tbl, "test_parsons.test_table")
 
     def test_query(self):
 
         # Test that queries match
-        self.civis.table_import(self.tbl, 'test_parsons.test_table')
+        self.civis.table_import(self.tbl, "test_parsons.test_table")
         tbl = self.civis.query("SELECT COUNT(*) FROM test_parsons.test_table")
-        self.assertEqual(tbl[0]['count'], '1')
+        self.assertEqual(tbl[0]["count"], "1")
 
     def test_to_civis(self):
 
         # Test that the to_civis() method works too
-        self.tbl.to_civis('test_parsons.test_table')
+        self.tbl.to_civis("test_parsons.test_table")
