@@ -12,7 +12,6 @@ _dir = os.path.dirname(__file__)
 
 
 class TestGmail(unittest.TestCase):
-
     @requests_mock.Mocker()
     def setUp(self, m):
         self.tmp_folder = "tmp/"
@@ -21,43 +20,54 @@ class TestGmail(unittest.TestCase):
 
         os.mkdir(self.tmp_folder)
 
-        with open(self.credentials_file, 'w') as f:
-            f.write(json.dumps({
-              "installed": {
-                "client_id": "someclientid.apps.googleusercontent.com",
-                "project_id": "some-project-id-12345",
-                "auth_uri": "https://accounts.google.com/o/oauth2/auth",
-                "token_uri": "https://www.googleapis.com/oauth2/v3/token",
-                "auth_provider_x509_cert_url": "https://www.googleapis.com/oauth2/v1/certs",
-                "client_secret": "someclientsecret",
-                "redirect_uris": ["urn:ietf:wg:oauth:2.0:oob", "http://localhost"]
-              }
-            }))
+        with open(self.credentials_file, "w") as f:
+            f.write(
+                json.dumps(
+                    {
+                        "installed": {
+                            "client_id": "someclientid.apps.googleusercontent.com",
+                            "project_id": "some-project-id-12345",
+                            "auth_uri": "https://accounts.google.com/o/oauth2/auth",
+                            "token_uri": "https://www.googleapis.com/oauth2/v3/token",
+                            "auth_provider_x509_cert_url": "https://www.googleapis.com/oauth2/v1/certs",  # noqa: E501
+                            "client_secret": "someclientsecret",
+                            "redirect_uris": [
+                                "urn:ietf:wg:oauth:2.0:oob",
+                                "http://localhost",
+                            ],
+                        }
+                    }
+                )
+            )
 
-        with open(self.token_file, 'w') as f:
-            f.write(json.dumps({
-              "access_token": "someaccesstoken",
-              "client_id": "some-client-id.apps.googleusercontent.com",
-              "client_secret": "someclientsecret",
-              "refresh_token": "1/refreshrate",
-              "token_expiry": "2030-02-20T23:28:09Z",
-              "token_uri": "https://www.googleapis.com/oauth2/v3/token",
-              "user_agent": None,
-              "revoke_uri": "https://oauth2.googleapis.com/revoke",
-              "id_token": None,
-              "id_token_jwt": None,
-              "token_response": {
-                "access_token": "someaccesstoken",
-                "expires_in": 3600000,
-                "scope": "https://www.googleapis.com/auth/gmail.send",
-                "token_type": "Bearer"
-              },
-              "scopes": ["https://www.googleapis.com/auth/gmail.send"],
-              "token_info_uri": "https://oauth2.googleapis.com/tokeninfo",
-              "invalid": False,
-              "_class": "OAuth2Credentials",
-              "_module": "oauth2client.client"
-            }))
+        with open(self.token_file, "w") as f:
+            f.write(
+                json.dumps(
+                    {
+                        "access_token": "someaccesstoken",
+                        "client_id": "some-client-id.apps.googleusercontent.com",
+                        "client_secret": "someclientsecret",
+                        "refresh_token": "1/refreshrate",
+                        "token_expiry": "2030-02-20T23:28:09Z",
+                        "token_uri": "https://www.googleapis.com/oauth2/v3/token",
+                        "user_agent": None,
+                        "revoke_uri": "https://oauth2.googleapis.com/revoke",
+                        "id_token": None,
+                        "id_token_jwt": None,
+                        "token_response": {
+                            "access_token": "someaccesstoken",
+                            "expires_in": 3600000,
+                            "scope": "https://www.googleapis.com/auth/gmail.send",
+                            "token_type": "Bearer",
+                        },
+                        "scopes": ["https://www.googleapis.com/auth/gmail.send"],
+                        "token_info_uri": "https://oauth2.googleapis.com/tokeninfo",
+                        "invalid": False,
+                        "_class": "OAuth2Credentials",
+                        "_module": "oauth2client.client",
+                    }
+                )
+            )
 
         self.gmail = Gmail(self.credentials_file, self.token_file)
 
@@ -71,20 +81,21 @@ class TestGmail(unittest.TestCase):
         subject = "This is a test email"
         message_text = "The is the message text of the email"
 
-        msg = self.gmail._create_message_simple(
-            sender, to, subject, message_text)
+        msg = self.gmail._create_message_simple(sender, to, subject, message_text)
         raw = self.gmail._encode_raw_message(msg)
 
         decoded = email.message_from_bytes(
-            base64.urlsafe_b64decode(bytes(raw['raw'], 'utf-8')))
+            base64.urlsafe_b64decode(bytes(raw["raw"], "utf-8"))
+        )
 
         expected_items = [
-            ('Content-Type', 'text/plain; charset="us-ascii"'),
-            ('MIME-Version', '1.0'),
-            ('Content-Transfer-Encoding', '7bit'),
-            ('to', to),
-            ('from', sender),
-            ('subject', subject)]
+            ("Content-Type", 'text/plain; charset="us-ascii"'),
+            ("MIME-Version", "1.0"),
+            ("Content-Transfer-Encoding", "7bit"),
+            ("to", to),
+            ("from", sender),
+            ("subject", subject),
+        ]
 
         # Check the metadata
         self.assertListEqual(decoded.items(), expected_items)
@@ -104,26 +115,32 @@ class TestGmail(unittest.TestCase):
         message_html = "<p>This is the html message part of the email</p>"
 
         msg = self.gmail._create_message_html(
-            sender, to, subject, message_text, message_html)
+            sender, to, subject, message_text, message_html
+        )
         raw = self.gmail._encode_raw_message(msg)
 
         decoded = email.message_from_bytes(
-            base64.urlsafe_b64decode(bytes(raw['raw'], 'utf-8')))
+            base64.urlsafe_b64decode(bytes(raw["raw"], "utf-8"))
+        )
 
         expected_items = [
-            ('Content-Type', 'multipart/alternative;\n boundary='),
-            ('MIME-Version', '1.0'),
-            ('subject', subject),
-            ('from', sender),
-            ('to', to)]
+            ("Content-Type", "multipart/alternative;\n boundary="),
+            ("MIME-Version", "1.0"),
+            ("subject", subject),
+            ("from", sender),
+            ("to", to),
+        ]
 
         # The boundary id changes everytime. Replace it with the beginnig to
         # avoid failures
         updated_items = []
         for i in decoded.items():
-            if 'Content-Type' in i[0] and 'multipart/alternative;\n boundary=' in i[1]:  # noqa
+            if (
+                "Content-Type" in i[0] and "multipart/alternative;\n boundary=" in i[1]
+            ):  # noqa
                 updated_items.append(
-                    ('Content-Type', 'multipart/alternative;\n boundary='))
+                    ("Content-Type", "multipart/alternative;\n boundary=")
+                )
             else:
                 updated_items.append((i[0], i[1]))
 
@@ -147,27 +164,31 @@ class TestGmail(unittest.TestCase):
         subject = "This is a test html email"
         message_html = "<p>This is the html message part of the email</p>"
 
-        msg = self.gmail._create_message_html(
-            sender, to, subject, '', message_html)
+        msg = self.gmail._create_message_html(sender, to, subject, "", message_html)
         raw = self.gmail._encode_raw_message(msg)
 
         decoded = email.message_from_bytes(
-            base64.urlsafe_b64decode(bytes(raw['raw'], 'utf-8')))
+            base64.urlsafe_b64decode(bytes(raw["raw"], "utf-8"))
+        )
 
         expected_items = [
-            ('Content-Type', 'multipart/alternative;\n boundary='),
-            ('MIME-Version', '1.0'),
-            ('subject', subject),
-            ('from', sender),
-            ('to', to)]
+            ("Content-Type", "multipart/alternative;\n boundary="),
+            ("MIME-Version", "1.0"),
+            ("subject", subject),
+            ("from", sender),
+            ("to", to),
+        ]
 
         # The boundary id changes everytime. Replace it with the beginnig to
         # avoid failures
         updated_items = []
         for i in decoded.items():
-            if 'Content-Type' in i[0] and 'multipart/alternative;\n boundary=' in i[1]:  # noqa
+            if (
+                "Content-Type" in i[0] and "multipart/alternative;\n boundary=" in i[1]
+            ):  # noqa
                 updated_items.append(
-                    ('Content-Type', 'multipart/alternative;\n boundary='))
+                    ("Content-Type", "multipart/alternative;\n boundary=")
+                )
             else:
                 updated_items.append((i[0], i[1]))
 
@@ -189,32 +210,38 @@ class TestGmail(unittest.TestCase):
         to = "Recepient <recepient@email.com>"
         subject = "This is a test email with attachements"
         message_text = "The is the message text of the email with attachments"
-        message_html = ("<p>This is the html message part of the email "
-                        "with attachments</p>")
-        attachments = [f'{_dir}/assets/loremipsum.txt']
+        message_html = (
+            "<p>This is the html message part of the email " "with attachments</p>"
+        )
+        attachments = [f"{_dir}/assets/loremipsum.txt"]
 
         msg = self.gmail._create_message_attachments(
-            sender, to, subject, message_text, attachments,
-            message_html=message_html)
+            sender, to, subject, message_text, attachments, message_html=message_html
+        )
         raw = self.gmail._encode_raw_message(msg)
 
         decoded = email.message_from_bytes(
-            base64.urlsafe_b64decode(bytes(raw['raw'], 'utf-8')))
+            base64.urlsafe_b64decode(bytes(raw["raw"], "utf-8"))
+        )
 
         expected_items = [
-            ('Content-Type', 'multipart/alternative;\n boundary='),
-            ('MIME-Version', '1.0'),
-            ('to', to),
-            ('from', sender),
-            ('subject', subject)]
+            ("Content-Type", "multipart/alternative;\n boundary="),
+            ("MIME-Version", "1.0"),
+            ("to", to),
+            ("from", sender),
+            ("subject", subject),
+        ]
 
         # The boundary id changes everytime. Replace it with the beginnig to
         # avoid failures
         updated_items = []
         for i in decoded.items():
-            if 'Content-Type' in i[0] and 'multipart/alternative;\n boundary=' in i[1]:  # noqa
+            if (
+                "Content-Type" in i[0] and "multipart/alternative;\n boundary=" in i[1]
+            ):  # noqa
                 updated_items.append(
-                    ('Content-Type', 'multipart/alternative;\n boundary='))
+                    ("Content-Type", "multipart/alternative;\n boundary=")
+                )
             else:
                 updated_items.append((i[0], i[1]))
 
@@ -228,16 +255,16 @@ class TestGmail(unittest.TestCase):
         self.assertEqual(parts[0].get_payload(), message_text)
         self.assertEqual(parts[1].get_payload(), message_html)
 
-        if os.linesep == '\r\n':
-            file = f'{_dir}/assets/loremipsum_b64_win_txt.txt'
+        if os.linesep == "\r\n":
+            file = f"{_dir}/assets/loremipsum_b64_win_txt.txt"
         else:
-            file = f'{_dir}/assets/loremipsum_b64_txt.txt'
+            file = f"{_dir}/assets/loremipsum_b64_txt.txt"
 
-        with open(file, 'r') as f:
+        with open(file, "r") as f:
             b64_txt = f.read()
         self.assertEqual(parts[2].get_payload(), b64_txt)
 
-        self.assertEqual(parts[2].get_content_type(), 'text/plain')
+        self.assertEqual(parts[2].get_content_type(), "text/plain")
 
         # Check the number of parts
         expected_parts = 4
@@ -248,32 +275,38 @@ class TestGmail(unittest.TestCase):
         to = "Recepient <recepient@email.com>"
         subject = "This is a test email with attachements"
         message_text = "The is the message text of the email with attachments"
-        message_html = ("<p>This is the html message part of the email "
-                        "with attachments</p>")
-        attachments = [f'{_dir}/assets/loremipsum.jpeg']
+        message_html = (
+            "<p>This is the html message part of the email " "with attachments</p>"
+        )
+        attachments = [f"{_dir}/assets/loremipsum.jpeg"]
 
         msg = self.gmail._create_message_attachments(
-            sender, to, subject, message_text, attachments,
-            message_html=message_html)
+            sender, to, subject, message_text, attachments, message_html=message_html
+        )
         raw = self.gmail._encode_raw_message(msg)
 
         decoded = email.message_from_bytes(
-            base64.urlsafe_b64decode(bytes(raw['raw'], 'utf-8')))
+            base64.urlsafe_b64decode(bytes(raw["raw"], "utf-8"))
+        )
 
         expected_items = [
-            ('Content-Type', 'multipart/alternative;\n boundary='),
-            ('MIME-Version', '1.0'),
-            ('to', to),
-            ('from', sender),
-            ('subject', subject)]
+            ("Content-Type", "multipart/alternative;\n boundary="),
+            ("MIME-Version", "1.0"),
+            ("to", to),
+            ("from", sender),
+            ("subject", subject),
+        ]
 
         # The boundary id changes everytime. Replace it with the beginnig to
         # avoid failures
         updated_items = []
         for i in decoded.items():
-            if 'Content-Type' in i[0] and 'multipart/alternative;\n boundary=' in i[1]:  # noqa
+            if (
+                "Content-Type" in i[0] and "multipart/alternative;\n boundary=" in i[1]
+            ):  # noqa
                 updated_items.append(
-                    ('Content-Type', 'multipart/alternative;\n boundary='))
+                    ("Content-Type", "multipart/alternative;\n boundary=")
+                )
             else:
                 updated_items.append((i[0], i[1]))
 
@@ -287,13 +320,13 @@ class TestGmail(unittest.TestCase):
         self.assertEqual(parts[0].get_payload(), message_text)
         self.assertEqual(parts[1].get_payload(), message_html)
 
-        with open(f'{_dir}/assets/loremipsum_b64_jpeg.txt', 'r') as f:
+        with open(f"{_dir}/assets/loremipsum_b64_jpeg.txt", "r") as f:
             b64_txt = f.read()
         self.assertEqual(parts[2].get_payload(), b64_txt)
 
         expected_id = f"<{attachments[0].split('/')[-1]}>"
-        self.assertEqual(parts[2].get('Content-ID'), expected_id)
-        self.assertEqual(parts[2].get_content_type(), 'image/jpeg')
+        self.assertEqual(parts[2].get("Content-ID"), expected_id)
+        self.assertEqual(parts[2].get_content_type(), "image/jpeg")
 
         # Check the number of parts
         expected_parts = 4
@@ -304,32 +337,38 @@ class TestGmail(unittest.TestCase):
         to = "Recepient <recepient@email.com>"
         subject = "This is a test email with attachements"
         message_text = "The is the message text of the email with attachments"
-        message_html = ("<p>This is the html message part of the email "
-                        "with attachments</p>")
-        attachments = [f'{_dir}/assets/loremipsum.m4a']
+        message_html = (
+            "<p>This is the html message part of the email " "with attachments</p>"
+        )
+        attachments = [f"{_dir}/assets/loremipsum.m4a"]
 
         msg = self.gmail._create_message_attachments(
-            sender, to, subject, message_text, attachments,
-            message_html=message_html)
+            sender, to, subject, message_text, attachments, message_html=message_html
+        )
         raw = self.gmail._encode_raw_message(msg)
 
         decoded = email.message_from_bytes(
-            base64.urlsafe_b64decode(bytes(raw['raw'], 'utf-8')))
+            base64.urlsafe_b64decode(bytes(raw["raw"], "utf-8"))
+        )
 
         expected_items = [
-            ('Content-Type', 'multipart/alternative;\n boundary='),
-            ('MIME-Version', '1.0'),
-            ('to', to),
-            ('from', sender),
-            ('subject', subject)]
+            ("Content-Type", "multipart/alternative;\n boundary="),
+            ("MIME-Version", "1.0"),
+            ("to", to),
+            ("from", sender),
+            ("subject", subject),
+        ]
 
         # The boundary id changes everytime. Replace it with the beginnig to
         # avoid failures
         updated_items = []
         for i in decoded.items():
-            if 'Content-Type' in i[0] and 'multipart/alternative;\n boundary=' in i[1]:  # noqa
+            if (
+                "Content-Type" in i[0] and "multipart/alternative;\n boundary=" in i[1]
+            ):  # noqa
                 updated_items.append(
-                    ('Content-Type', 'multipart/alternative;\n boundary='))
+                    ("Content-Type", "multipart/alternative;\n boundary=")
+                )
             else:
                 updated_items.append((i[0], i[1]))
 
@@ -343,11 +382,11 @@ class TestGmail(unittest.TestCase):
         self.assertEqual(parts[0].get_payload(), message_text)
         self.assertEqual(parts[1].get_payload(), message_html)
 
-        with open(f'{_dir}/assets/loremipsum_b64_m4a.txt', 'r') as f:
+        with open(f"{_dir}/assets/loremipsum_b64_m4a.txt", "r") as f:
             b64_txt = f.read()
         self.assertEqual(parts[2].get_payload(), b64_txt)
 
-        self.assertEqual(parts[2].get_content_maintype(), 'audio')
+        self.assertEqual(parts[2].get_content_maintype(), "audio")
 
         # Check the number of parts
         expected_parts = 4
@@ -358,32 +397,38 @@ class TestGmail(unittest.TestCase):
         to = "Recepient <recepient@email.com>"
         subject = "This is a test email with attachements"
         message_text = "The is the message text of the email with attachments"
-        message_html = ("<p>This is the html message part of the email "
-                        "with attachments</p>")
-        attachments = [f'{_dir}/assets/loremipsum.mp3']
+        message_html = (
+            "<p>This is the html message part of the email " "with attachments</p>"
+        )
+        attachments = [f"{_dir}/assets/loremipsum.mp3"]
 
         msg = self.gmail._create_message_attachments(
-            sender, to, subject, message_text, attachments,
-            message_html=message_html)
+            sender, to, subject, message_text, attachments, message_html=message_html
+        )
         raw = self.gmail._encode_raw_message(msg)
 
         decoded = email.message_from_bytes(
-            base64.urlsafe_b64decode(bytes(raw['raw'], 'utf-8')))
+            base64.urlsafe_b64decode(bytes(raw["raw"], "utf-8"))
+        )
 
         expected_items = [
-            ('Content-Type', 'multipart/alternative;\n boundary='),
-            ('MIME-Version', '1.0'),
-            ('to', to),
-            ('from', sender),
-            ('subject', subject)]
+            ("Content-Type", "multipart/alternative;\n boundary="),
+            ("MIME-Version", "1.0"),
+            ("to", to),
+            ("from", sender),
+            ("subject", subject),
+        ]
 
         # The boundary id changes everytime. Replace it with the beginnig to
         # avoid failures
         updated_items = []
         for i in decoded.items():
-            if 'Content-Type' in i[0] and 'multipart/alternative;\n boundary=' in i[1]:  # noqa
+            if (
+                "Content-Type" in i[0] and "multipart/alternative;\n boundary=" in i[1]
+            ):  # noqa
                 updated_items.append(
-                    ('Content-Type', 'multipart/alternative;\n boundary='))
+                    ("Content-Type", "multipart/alternative;\n boundary=")
+                )
             else:
                 updated_items.append((i[0], i[1]))
 
@@ -397,11 +442,11 @@ class TestGmail(unittest.TestCase):
         self.assertEqual(parts[0].get_payload(), message_text)
         self.assertEqual(parts[1].get_payload(), message_html)
 
-        with open(f'{_dir}/assets/loremipsum_b64_mp3.txt', 'r') as f:
+        with open(f"{_dir}/assets/loremipsum_b64_mp3.txt", "r") as f:
             b64_txt = f.read()
         self.assertEqual(parts[2].get_payload(), b64_txt)
 
-        self.assertEqual(parts[2].get_content_type(), 'audio/mpeg')
+        self.assertEqual(parts[2].get_content_type(), "audio/mpeg")
 
         # Check the number of parts
         expected_parts = 4
@@ -412,32 +457,38 @@ class TestGmail(unittest.TestCase):
         to = "Recepient <recepient@email.com>"
         subject = "This is a test email with attachements"
         message_text = "The is the message text of the email with attachments"
-        message_html = ("<p>This is the html message part of the email "
-                        "with attachments</p>")
-        attachments = [f'{_dir}/assets/loremipsum.mp4']
+        message_html = (
+            "<p>This is the html message part of the email " "with attachments</p>"
+        )
+        attachments = [f"{_dir}/assets/loremipsum.mp4"]
 
         msg = self.gmail._create_message_attachments(
-            sender, to, subject, message_text, attachments,
-            message_html=message_html)
+            sender, to, subject, message_text, attachments, message_html=message_html
+        )
         raw = self.gmail._encode_raw_message(msg)
 
         decoded = email.message_from_bytes(
-            base64.urlsafe_b64decode(bytes(raw['raw'], 'utf-8')))
+            base64.urlsafe_b64decode(bytes(raw["raw"], "utf-8"))
+        )
 
         expected_items = [
-            ('Content-Type', 'multipart/alternative;\n boundary='),
-            ('MIME-Version', '1.0'),
-            ('to', to),
-            ('from', sender),
-            ('subject', subject)]
+            ("Content-Type", "multipart/alternative;\n boundary="),
+            ("MIME-Version", "1.0"),
+            ("to", to),
+            ("from", sender),
+            ("subject", subject),
+        ]
 
         # The boundary id changes everytime. Replace it with the beginnig to
         # avoid failures
         updated_items = []
         for i in decoded.items():
-            if 'Content-Type' in i[0] and 'multipart/alternative;\n boundary=' in i[1]:  # noqa
+            if (
+                "Content-Type" in i[0] and "multipart/alternative;\n boundary=" in i[1]
+            ):  # noqa
                 updated_items.append(
-                    ('Content-Type', 'multipart/alternative;\n boundary='))
+                    ("Content-Type", "multipart/alternative;\n boundary=")
+                )
             else:
                 updated_items.append((i[0], i[1]))
 
@@ -451,11 +502,11 @@ class TestGmail(unittest.TestCase):
         self.assertEqual(parts[0].get_payload(), message_text)
         self.assertEqual(parts[1].get_payload(), message_html)
 
-        with open(f'{_dir}/assets/loremipsum_b64_mp4.txt', 'r') as f:
+        with open(f"{_dir}/assets/loremipsum_b64_mp4.txt", "r") as f:
             b64_txt = f.read()
         self.assertEqual(parts[2].get_payload(), b64_txt)
 
-        self.assertEqual(parts[2].get_content_type(), 'video/mp4')
+        self.assertEqual(parts[2].get_content_type(), "video/mp4")
 
         # Check the number of parts
         expected_parts = 4
@@ -466,33 +517,39 @@ class TestGmail(unittest.TestCase):
         to = "Recepient <recepient@email.com>"
         subject = "This is a test email with attachements"
         message_text = "The is the message text of the email with attachments"
-        message_html = ("<p>This is the html message part of the email "
-                        "with attachments</p>")
-        attachments = [f'{_dir}/assets/loremipsum.pdf']
+        message_html = (
+            "<p>This is the html message part of the email " "with attachments</p>"
+        )
+        attachments = [f"{_dir}/assets/loremipsum.pdf"]
 
         msg = self.gmail._create_message_attachments(
-            sender, to, subject, message_text, attachments,
-            message_html=message_html)
+            sender, to, subject, message_text, attachments, message_html=message_html
+        )
 
         raw = self.gmail._encode_raw_message(msg)
 
         decoded = email.message_from_bytes(
-            base64.urlsafe_b64decode(bytes(raw['raw'], 'utf-8')))
+            base64.urlsafe_b64decode(bytes(raw["raw"], "utf-8"))
+        )
 
         expected_items = [
-            ('Content-Type', 'multipart/alternative;\n boundary='),
-            ('MIME-Version', '1.0'),
-            ('to', to),
-            ('from', sender),
-            ('subject', subject)]
+            ("Content-Type", "multipart/alternative;\n boundary="),
+            ("MIME-Version", "1.0"),
+            ("to", to),
+            ("from", sender),
+            ("subject", subject),
+        ]
 
         # The boundary id changes everytime. Replace it with the beginnig to
         # avoid failures
         updated_items = []
         for i in decoded.items():
-            if 'Content-Type' in i[0] and 'multipart/alternative;\n boundary=' in i[1]:  # noqa
+            if (
+                "Content-Type" in i[0] and "multipart/alternative;\n boundary=" in i[1]
+            ):  # noqa
                 updated_items.append(
-                    ('Content-Type', 'multipart/alternative;\n boundary='))
+                    ("Content-Type", "multipart/alternative;\n boundary=")
+                )
             else:
                 updated_items.append((i[0], i[1]))
 
@@ -506,11 +563,11 @@ class TestGmail(unittest.TestCase):
         self.assertEqual(parts[0].get_payload(), message_text)
         self.assertEqual(parts[1].get_payload(), message_html)
 
-        with open(f'{_dir}/assets/loremipsum_b64_pdf.txt', 'r') as f:
+        with open(f"{_dir}/assets/loremipsum_b64_pdf.txt", "r") as f:
             b64_txt = f.read()
         self.assertEqual(parts[2].get_payload(), b64_txt)
 
-        self.assertEqual(parts[2].get_content_type(), 'application/pdf')
+        self.assertEqual(parts[2].get_content_type(), "application/pdf")
 
         # Check the number of parts
         expected_parts = 4
@@ -524,15 +581,16 @@ class TestGmail(unittest.TestCase):
             {"email": "Sender sender@email.com", "expected": False},
             {"email": "Sender <sender2email.com>", "expected": False},
             {"email": "Sender <sender@email,com>", "expected": True},
-            {"email": "Sender <sender+alias@email,com>", "expected": True}
+            {"email": "Sender <sender+alias@email,com>", "expected": True},
         ]
 
         for e in emails:
-            if e['expected']:
-                self.assertTrue(self.gmail._validate_email_string(e['email']))
+            if e["expected"]:
+                self.assertTrue(self.gmail._validate_email_string(e["email"]))
             else:
                 self.assertRaises(
-                    ValueError, self.gmail._validate_email_string, e['email'])
+                    ValueError, self.gmail._validate_email_string, e["email"]
+                )
 
     # TODO test sending emails
 
