@@ -29,11 +29,13 @@ def test_connection():
 
 @pytest.mark.parametrize(
     ["username", "password", "api_token"],
-    [(None, None,  None),
-     (None, "pass",  "token"),
-     ("user", None, "token"),
-     ("user", "pass", None),
-     ])
+    [
+        (None, None, None),
+        (None, "pass", "token"),
+        ("user", None, "token"),
+        ("user", "pass", None),
+    ],
+)
 def test_init_error(username, password, api_token):
     remove_from_env("PDI_USERNAME", "PDI_PASSWORD", "PDI_API_TOKEN")
     with pytest.raises(KeyError):
@@ -42,10 +44,14 @@ def test_init_error(username, password, api_token):
 
 @pytest.mark.parametrize(
     ["obj", "exp_obj"],
-    [({"a": "a", "b": None, "c": "c"}, {"a": "a", "c": "c"}),
-     ([{"a": "a", "b": None, "c": "c"}, {"a": "a", "c": None}],
-      [{"a": "a", "c": "c"}, {"a": "a"}]),
-     ("string", "string"),
-     ])
+    [
+        ({"a": "a", "b": None, "c": "c"}, {"a": "a", "c": "c"}),
+        (
+            [{"a": "a", "b": None, "c": "c"}, {"a": "a", "c": None}],
+            [{"a": "a", "c": "c"}, {"a": "a"}],
+        ),
+        ("string", "string"),
+    ],
+)
 def test_clean_dict(mock_pdi, obj, exp_obj):
     assert mock_pdi._clean_dict(obj) == exp_obj
